aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorOla Rozenfeld <olaola@google.com>2019-06-06 12:35:26 -0400
committerGitHub <noreply@github.com>2019-06-06 12:35:26 -0400
commita5c577357528b33a4adff88c0c7911dd086c6923 (patch)
tree76d0395493558c837e0a2817eddc8d73554fb2df
parenta6504b14665c6a7d9a0f2c5cbfebe865863e3c1e (diff)
downloadbazelbuild-remote-apis-a5c577357528b33a4adff88c0c7911dd086c6923.tar.gz
Wrapping all enums in messages for clarity in C++/Py. (#85)
Fixes #56.
-rwxr-xr-xbuild/bazel/remote/execution/v2/remote_execution.pb.go690
-rw-r--r--build/bazel/remote/execution/v2/remote_execution.proto65
2 files changed, 432 insertions, 323 deletions
diff --git a/build/bazel/remote/execution/v2/remote_execution.pb.go b/build/bazel/remote/execution/v2/remote_execution.pb.go
index cfe44b1..eb5411a 100755
--- a/build/bazel/remote/execution/v2/remote_execution.pb.go
+++ b/build/bazel/remote/execution/v2/remote_execution.pb.go
@@ -28,97 +28,100 @@ var _ = math.Inf
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package
-type DigestFunction int32
+type ExecutionStage_Value int32
const (
- DigestFunction_UNKNOWN DigestFunction = 0
- DigestFunction_SHA256 DigestFunction = 1
- DigestFunction_SHA1 DigestFunction = 2
- DigestFunction_MD5 DigestFunction = 3
+ ExecutionStage_UNKNOWN ExecutionStage_Value = 0
+ ExecutionStage_CACHE_CHECK ExecutionStage_Value = 1
+ ExecutionStage_QUEUED ExecutionStage_Value = 2
+ ExecutionStage_EXECUTING ExecutionStage_Value = 3
+ ExecutionStage_COMPLETED ExecutionStage_Value = 4
)
-var DigestFunction_name = map[int32]string{
+var ExecutionStage_Value_name = map[int32]string{
0: "UNKNOWN",
- 1: "SHA256",
- 2: "SHA1",
- 3: "MD5",
+ 1: "CACHE_CHECK",
+ 2: "QUEUED",
+ 3: "EXECUTING",
+ 4: "COMPLETED",
}
-var DigestFunction_value = map[string]int32{
- "UNKNOWN": 0,
- "SHA256": 1,
- "SHA1": 2,
- "MD5": 3,
+var ExecutionStage_Value_value = map[string]int32{
+ "UNKNOWN": 0,
+ "CACHE_CHECK": 1,
+ "QUEUED": 2,
+ "EXECUTING": 3,
+ "COMPLETED": 4,
}
-func (x DigestFunction) String() string {
- return proto.EnumName(DigestFunction_name, int32(x))
+func (x ExecutionStage_Value) String() string {
+ return proto.EnumName(ExecutionStage_Value_name, int32(x))
}
-func (DigestFunction) EnumDescriptor() ([]byte, []int) {
- return fileDescriptor_c43847ba40caac95, []int{0}
+func (ExecutionStage_Value) EnumDescriptor() ([]byte, []int) {
+ return fileDescriptor_c43847ba40caac95, []int{19, 0}
}
-type ExecuteOperationMetadata_Stage int32
+type DigestFunction_Value int32
const (
- ExecuteOperationMetadata_UNKNOWN ExecuteOperationMetadata_Stage = 0
- ExecuteOperationMetadata_CACHE_CHECK ExecuteOperationMetadata_Stage = 1
- ExecuteOperationMetadata_QUEUED ExecuteOperationMetadata_Stage = 2
- ExecuteOperationMetadata_EXECUTING ExecuteOperationMetadata_Stage = 3
- ExecuteOperationMetadata_COMPLETED ExecuteOperationMetadata_Stage = 4
+ DigestFunction_UNKNOWN DigestFunction_Value = 0
+ DigestFunction_SHA256 DigestFunction_Value = 1
+ DigestFunction_SHA1 DigestFunction_Value = 2
+ DigestFunction_MD5 DigestFunction_Value = 3
+ DigestFunction_VSO DigestFunction_Value = 4
)
-var ExecuteOperationMetadata_Stage_name = map[int32]string{
+var DigestFunction_Value_name = map[int32]string{
0: "UNKNOWN",
- 1: "CACHE_CHECK",
- 2: "QUEUED",
- 3: "EXECUTING",
- 4: "COMPLETED",
+ 1: "SHA256",
+ 2: "SHA1",
+ 3: "MD5",
+ 4: "VSO",
}
-var ExecuteOperationMetadata_Stage_value = map[string]int32{
- "UNKNOWN": 0,
- "CACHE_CHECK": 1,
- "QUEUED": 2,
- "EXECUTING": 3,
- "COMPLETED": 4,
+var DigestFunction_Value_value = map[string]int32{
+ "UNKNOWN": 0,
+ "SHA256": 1,
+ "SHA1": 2,
+ "MD5": 3,
+ "VSO": 4,
}
-func (x ExecuteOperationMetadata_Stage) String() string {
- return proto.EnumName(ExecuteOperationMetadata_Stage_name, int32(x))
+func (x DigestFunction_Value) String() string {
+ return proto.EnumName(DigestFunction_Value_name, int32(x))
}
-func (ExecuteOperationMetadata_Stage) EnumDescriptor() ([]byte, []int) {
- return fileDescriptor_c43847ba40caac95, []int{19, 0}
+func (DigestFunction_Value) EnumDescriptor() ([]byte, []int) {
+ return fileDescriptor_c43847ba40caac95, []int{34, 0}
}
-type CacheCapabilities_SymlinkAbsolutePathStrategy int32
+type SymlinkAbsolutePathStrategy_Value int32
const (
- CacheCapabilities_UNKNOWN CacheCapabilities_SymlinkAbsolutePathStrategy = 0
- CacheCapabilities_DISALLOWED CacheCapabilities_SymlinkAbsolutePathStrategy = 1
- CacheCapabilities_ALLOWED CacheCapabilities_SymlinkAbsolutePathStrategy = 2
+ SymlinkAbsolutePathStrategy_UNKNOWN SymlinkAbsolutePathStrategy_Value = 0
+ SymlinkAbsolutePathStrategy_DISALLOWED SymlinkAbsolutePathStrategy_Value = 1
+ SymlinkAbsolutePathStrategy_ALLOWED SymlinkAbsolutePathStrategy_Value = 2
)
-var CacheCapabilities_SymlinkAbsolutePathStrategy_name = map[int32]string{
+var SymlinkAbsolutePathStrategy_Value_name = map[int32]string{
0: "UNKNOWN",
1: "DISALLOWED",
2: "ALLOWED",
}
-var CacheCapabilities_SymlinkAbsolutePathStrategy_value = map[string]int32{
+var SymlinkAbsolutePathStrategy_Value_value = map[string]int32{
"UNKNOWN": 0,
"DISALLOWED": 1,
"ALLOWED": 2,
}
-func (x CacheCapabilities_SymlinkAbsolutePathStrategy) String() string {
- return proto.EnumName(CacheCapabilities_SymlinkAbsolutePathStrategy_name, int32(x))
+func (x SymlinkAbsolutePathStrategy_Value) String() string {
+ return proto.EnumName(SymlinkAbsolutePathStrategy_Value_name, int32(x))
}
-func (CacheCapabilities_SymlinkAbsolutePathStrategy) EnumDescriptor() ([]byte, []int) {
- return fileDescriptor_c43847ba40caac95, []int{35, 0}
+func (SymlinkAbsolutePathStrategy_Value) EnumDescriptor() ([]byte, []int) {
+ return fileDescriptor_c43847ba40caac95, []int{37, 0}
}
type Action struct {
@@ -1340,21 +1343,52 @@ func (m *ExecuteResponse) GetMessage() string {
return ""
}
+type ExecutionStage struct {
+ XXX_NoUnkeyedLiteral struct{} `json:"-"`
+ XXX_unrecognized []byte `json:"-"`
+ XXX_sizecache int32 `json:"-"`
+}
+
+func (m *ExecutionStage) Reset() { *m = ExecutionStage{} }
+func (m *ExecutionStage) String() string { return proto.CompactTextString(m) }
+func (*ExecutionStage) ProtoMessage() {}
+func (*ExecutionStage) Descriptor() ([]byte, []int) {
+ return fileDescriptor_c43847ba40caac95, []int{19}
+}
+
+func (m *ExecutionStage) XXX_Unmarshal(b []byte) error {
+ return xxx_messageInfo_ExecutionStage.Unmarshal(m, b)
+}
+func (m *ExecutionStage) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
+ return xxx_messageInfo_ExecutionStage.Marshal(b, m, deterministic)
+}
+func (m *ExecutionStage) XXX_Merge(src proto.Message) {
+ xxx_messageInfo_ExecutionStage.Merge(m, src)
+}
+func (m *ExecutionStage) XXX_Size() int {
+ return xxx_messageInfo_ExecutionStage.Size(m)
+}
+func (m *ExecutionStage) XXX_DiscardUnknown() {
+ xxx_messageInfo_ExecutionStage.DiscardUnknown(m)
+}
+
+var xxx_messageInfo_ExecutionStage proto.InternalMessageInfo
+
type ExecuteOperationMetadata struct {
- Stage ExecuteOperationMetadata_Stage `protobuf:"varint,1,opt,name=stage,proto3,enum=build.bazel.remote.execution.v2.ExecuteOperationMetadata_Stage" json:"stage,omitempty"`
- ActionDigest *Digest `protobuf:"bytes,2,opt,name=action_digest,json=actionDigest,proto3" json:"action_digest,omitempty"`
- StdoutStreamName string `protobuf:"bytes,3,opt,name=stdout_stream_name,json=stdoutStreamName,proto3" json:"stdout_stream_name,omitempty"`
- StderrStreamName string `protobuf:"bytes,4,opt,name=stderr_stream_name,json=stderrStreamName,proto3" json:"stderr_stream_name,omitempty"`
- XXX_NoUnkeyedLiteral struct{} `json:"-"`
- XXX_unrecognized []byte `json:"-"`
- XXX_sizecache int32 `json:"-"`
+ Stage ExecutionStage_Value `protobuf:"varint,1,opt,name=stage,proto3,enum=build.bazel.remote.execution.v2.ExecutionStage_Value" json:"stage,omitempty"`
+ ActionDigest *Digest `protobuf:"bytes,2,opt,name=action_digest,json=actionDigest,proto3" json:"action_digest,omitempty"`
+ StdoutStreamName string `protobuf:"bytes,3,opt,name=stdout_stream_name,json=stdoutStreamName,proto3" json:"stdout_stream_name,omitempty"`
+ StderrStreamName string `protobuf:"bytes,4,opt,name=stderr_stream_name,json=stderrStreamName,proto3" json:"stderr_stream_name,omitempty"`
+ XXX_NoUnkeyedLiteral struct{} `json:"-"`
+ XXX_unrecognized []byte `json:"-"`
+ XXX_sizecache int32 `json:"-"`
}
func (m *ExecuteOperationMetadata) Reset() { *m = ExecuteOperationMetadata{} }
func (m *ExecuteOperationMetadata) String() string { return proto.CompactTextString(m) }
func (*ExecuteOperationMetadata) ProtoMessage() {}
func (*ExecuteOperationMetadata) Descriptor() ([]byte, []int) {
- return fileDescriptor_c43847ba40caac95, []int{19}
+ return fileDescriptor_c43847ba40caac95, []int{20}
}
func (m *ExecuteOperationMetadata) XXX_Unmarshal(b []byte) error {
@@ -1375,11 +1409,11 @@ func (m *ExecuteOperationMetadata) XXX_DiscardUnknown() {
var xxx_messageInfo_ExecuteOperationMetadata proto.InternalMessageInfo
-func (m *ExecuteOperationMetadata) GetStage() ExecuteOperationMetadata_Stage {
+func (m *ExecuteOperationMetadata) GetStage() ExecutionStage_Value {
if m != nil {
return m.Stage
}
- return ExecuteOperationMetadata_UNKNOWN
+ return ExecutionStage_UNKNOWN
}
func (m *ExecuteOperationMetadata) GetActionDigest() *Digest {
@@ -1414,7 +1448,7 @@ func (m *WaitExecutionRequest) Reset() { *m = WaitExecutionRequest{} }
func (m *WaitExecutionRequest) String() string { return proto.CompactTextString(m) }
func (*WaitExecutionRequest) ProtoMessage() {}
func (*WaitExecutionRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_c43847ba40caac95, []int{20}
+ return fileDescriptor_c43847ba40caac95, []int{21}
}
func (m *WaitExecutionRequest) XXX_Unmarshal(b []byte) error {
@@ -1457,7 +1491,7 @@ func (m *GetActionResultRequest) Reset() { *m = GetActionResultRequest{}
func (m *GetActionResultRequest) String() string { return proto.CompactTextString(m) }
func (*GetActionResultRequest) ProtoMessage() {}
func (*GetActionResultRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_c43847ba40caac95, []int{21}
+ return fileDescriptor_c43847ba40caac95, []int{22}
}
func (m *GetActionResultRequest) XXX_Unmarshal(b []byte) error {
@@ -1527,7 +1561,7 @@ func (m *UpdateActionResultRequest) Reset() { *m = UpdateActionResultReq
func (m *UpdateActionResultRequest) String() string { return proto.CompactTextString(m) }
func (*UpdateActionResultRequest) ProtoMessage() {}
func (*UpdateActionResultRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_c43847ba40caac95, []int{22}
+ return fileDescriptor_c43847ba40caac95, []int{23}
}
func (m *UpdateActionResultRequest) XXX_Unmarshal(b []byte) error {
@@ -1588,7 +1622,7 @@ func (m *FindMissingBlobsRequest) Reset() { *m = FindMissingBlobsRequest
func (m *FindMissingBlobsRequest) String() string { return proto.CompactTextString(m) }
func (*FindMissingBlobsRequest) ProtoMessage() {}
func (*FindMissingBlobsRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_c43847ba40caac95, []int{23}
+ return fileDescriptor_c43847ba40caac95, []int{24}
}
func (m *FindMissingBlobsRequest) XXX_Unmarshal(b []byte) error {
@@ -1634,7 +1668,7 @@ func (m *FindMissingBlobsResponse) Reset() { *m = FindMissingBlobsRespon
func (m *FindMissingBlobsResponse) String() string { return proto.CompactTextString(m) }
func (*FindMissingBlobsResponse) ProtoMessage() {}
func (*FindMissingBlobsResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_c43847ba40caac95, []int{24}
+ return fileDescriptor_c43847ba40caac95, []int{25}
}
func (m *FindMissingBlobsResponse) XXX_Unmarshal(b []byte) error {
@@ -1674,7 +1708,7 @@ func (m *BatchUpdateBlobsRequest) Reset() { *m = BatchUpdateBlobsRequest
func (m *BatchUpdateBlobsRequest) String() string { return proto.CompactTextString(m) }
func (*BatchUpdateBlobsRequest) ProtoMessage() {}
func (*BatchUpdateBlobsRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_c43847ba40caac95, []int{25}
+ return fileDescriptor_c43847ba40caac95, []int{26}
}
func (m *BatchUpdateBlobsRequest) XXX_Unmarshal(b []byte) error {
@@ -1721,7 +1755,7 @@ func (m *BatchUpdateBlobsRequest_Request) Reset() { *m = BatchUpdateBlob
func (m *BatchUpdateBlobsRequest_Request) String() string { return proto.CompactTextString(m) }
func (*BatchUpdateBlobsRequest_Request) ProtoMessage() {}
func (*BatchUpdateBlobsRequest_Request) Descriptor() ([]byte, []int) {
- return fileDescriptor_c43847ba40caac95, []int{25, 0}
+ return fileDescriptor_c43847ba40caac95, []int{26, 0}
}
func (m *BatchUpdateBlobsRequest_Request) XXX_Unmarshal(b []byte) error {
@@ -1767,7 +1801,7 @@ func (m *BatchUpdateBlobsResponse) Reset() { *m = BatchUpdateBlobsRespon
func (m *BatchUpdateBlobsResponse) String() string { return proto.CompactTextString(m) }
func (*BatchUpdateBlobsResponse) ProtoMessage() {}
func (*BatchUpdateBlobsResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_c43847ba40caac95, []int{26}
+ return fileDescriptor_c43847ba40caac95, []int{27}
}
func (m *BatchUpdateBlobsResponse) XXX_Unmarshal(b []byte) error {
@@ -1807,7 +1841,7 @@ func (m *BatchUpdateBlobsResponse_Response) Reset() { *m = BatchUpdateBl
func (m *BatchUpdateBlobsResponse_Response) String() string { return proto.CompactTextString(m) }
func (*BatchUpdateBlobsResponse_Response) ProtoMessage() {}
func (*BatchUpdateBlobsResponse_Response) Descriptor() ([]byte, []int) {
- return fileDescriptor_c43847ba40caac95, []int{26, 0}
+ return fileDescriptor_c43847ba40caac95, []int{27, 0}
}
func (m *BatchUpdateBlobsResponse_Response) XXX_Unmarshal(b []byte) error {
@@ -1854,7 +1888,7 @@ func (m *BatchReadBlobsRequest) Reset() { *m = BatchReadBlobsRequest{} }
func (m *BatchReadBlobsRequest) String() string { return proto.CompactTextString(m) }
func (*BatchReadBlobsRequest) ProtoMessage() {}
func (*BatchReadBlobsRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_c43847ba40caac95, []int{27}
+ return fileDescriptor_c43847ba40caac95, []int{28}
}
func (m *BatchReadBlobsRequest) XXX_Unmarshal(b []byte) error {
@@ -1900,7 +1934,7 @@ func (m *BatchReadBlobsResponse) Reset() { *m = BatchReadBlobsResponse{}
func (m *BatchReadBlobsResponse) String() string { return proto.CompactTextString(m) }
func (*BatchReadBlobsResponse) ProtoMessage() {}
func (*BatchReadBlobsResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_c43847ba40caac95, []int{28}
+ return fileDescriptor_c43847ba40caac95, []int{29}
}
func (m *BatchReadBlobsResponse) XXX_Unmarshal(b []byte) error {
@@ -1941,7 +1975,7 @@ func (m *BatchReadBlobsResponse_Response) Reset() { *m = BatchReadBlobsR
func (m *BatchReadBlobsResponse_Response) String() string { return proto.CompactTextString(m) }
func (*BatchReadBlobsResponse_Response) ProtoMessage() {}
func (*BatchReadBlobsResponse_Response) Descriptor() ([]byte, []int) {
- return fileDescriptor_c43847ba40caac95, []int{28, 0}
+ return fileDescriptor_c43847ba40caac95, []int{29, 0}
}
func (m *BatchReadBlobsResponse_Response) XXX_Unmarshal(b []byte) error {
@@ -1997,7 +2031,7 @@ func (m *GetTreeRequest) Reset() { *m = GetTreeRequest{} }
func (m *GetTreeRequest) String() string { return proto.CompactTextString(m) }
func (*GetTreeRequest) ProtoMessage() {}
func (*GetTreeRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_c43847ba40caac95, []int{29}
+ return fileDescriptor_c43847ba40caac95, []int{30}
}
func (m *GetTreeRequest) XXX_Unmarshal(b []byte) error {
@@ -2058,7 +2092,7 @@ func (m *GetTreeResponse) Reset() { *m = GetTreeResponse{} }
func (m *GetTreeResponse) String() string { return proto.CompactTextString(m) }
func (*GetTreeResponse) ProtoMessage() {}
func (*GetTreeResponse) Descriptor() ([]byte, []int) {
- return fileDescriptor_c43847ba40caac95, []int{30}
+ return fileDescriptor_c43847ba40caac95, []int{31}
}
func (m *GetTreeResponse) XXX_Unmarshal(b []byte) error {
@@ -2104,7 +2138,7 @@ func (m *GetCapabilitiesRequest) Reset() { *m = GetCapabilitiesRequest{}
func (m *GetCapabilitiesRequest) String() string { return proto.CompactTextString(m) }
func (*GetCapabilitiesRequest) ProtoMessage() {}
func (*GetCapabilitiesRequest) Descriptor() ([]byte, []int) {
- return fileDescriptor_c43847ba40caac95, []int{31}
+ return fileDescriptor_c43847ba40caac95, []int{32}
}
func (m *GetCapabilitiesRequest) XXX_Unmarshal(b []byte) error {
@@ -2147,7 +2181,7 @@ func (m *ServerCapabilities) Reset() { *m = ServerCapabilities{} }
func (m *ServerCapabilities) String() string { return proto.CompactTextString(m) }
func (*ServerCapabilities) ProtoMessage() {}
func (*ServerCapabilities) Descriptor() ([]byte, []int) {
- return fileDescriptor_c43847ba40caac95, []int{32}
+ return fileDescriptor_c43847ba40caac95, []int{33}
}
func (m *ServerCapabilities) XXX_Unmarshal(b []byte) error {
@@ -2203,6 +2237,37 @@ func (m *ServerCapabilities) GetHighApiVersion() *semver.SemVer {
return nil
}
+type DigestFunction struct {
+ XXX_NoUnkeyedLiteral struct{} `json:"-"`
+ XXX_unrecognized []byte `json:"-"`
+ XXX_sizecache int32 `json:"-"`
+}
+
+func (m *DigestFunction) Reset() { *m = DigestFunction{} }
+func (m *DigestFunction) String() string { return proto.CompactTextString(m) }
+func (*DigestFunction) ProtoMessage() {}
+func (*DigestFunction) Descriptor() ([]byte, []int) {
+ return fileDescriptor_c43847ba40caac95, []int{34}
+}
+
+func (m *DigestFunction) XXX_Unmarshal(b []byte) error {
+ return xxx_messageInfo_DigestFunction.Unmarshal(m, b)
+}
+func (m *DigestFunction) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
+ return xxx_messageInfo_DigestFunction.Marshal(b, m, deterministic)
+}
+func (m *DigestFunction) XXX_Merge(src proto.Message) {
+ xxx_messageInfo_DigestFunction.Merge(m, src)
+}
+func (m *DigestFunction) XXX_Size() int {
+ return xxx_messageInfo_DigestFunction.Size(m)
+}
+func (m *DigestFunction) XXX_DiscardUnknown() {
+ xxx_messageInfo_DigestFunction.DiscardUnknown(m)
+}
+
+var xxx_messageInfo_DigestFunction proto.InternalMessageInfo
+
type ActionCacheUpdateCapabilities struct {
UpdateEnabled bool `protobuf:"varint,1,opt,name=update_enabled,json=updateEnabled,proto3" json:"update_enabled,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
@@ -2214,7 +2279,7 @@ func (m *ActionCacheUpdateCapabilities) Reset() { *m = ActionCacheUpdate
func (m *ActionCacheUpdateCapabilities) String() string { return proto.CompactTextString(m) }
func (*ActionCacheUpdateCapabilities) ProtoMessage() {}
func (*ActionCacheUpdateCapabilities) Descriptor() ([]byte, []int) {
- return fileDescriptor_c43847ba40caac95, []int{33}
+ return fileDescriptor_c43847ba40caac95, []int{35}
}
func (m *ActionCacheUpdateCapabilities) XXX_Unmarshal(b []byte) error {
@@ -2253,7 +2318,7 @@ func (m *PriorityCapabilities) Reset() { *m = PriorityCapabilities{} }
func (m *PriorityCapabilities) String() string { return proto.CompactTextString(m) }
func (*PriorityCapabilities) ProtoMessage() {}
func (*PriorityCapabilities) Descriptor() ([]byte, []int) {
- return fileDescriptor_c43847ba40caac95, []int{34}
+ return fileDescriptor_c43847ba40caac95, []int{36}
}
func (m *PriorityCapabilities) XXX_Unmarshal(b []byte) error {
@@ -2293,7 +2358,7 @@ func (m *PriorityCapabilities_PriorityRange) Reset() { *m = PriorityCapa
func (m *PriorityCapabilities_PriorityRange) String() string { return proto.CompactTextString(m) }
func (*PriorityCapabilities_PriorityRange) ProtoMessage() {}
func (*PriorityCapabilities_PriorityRange) Descriptor() ([]byte, []int) {
- return fileDescriptor_c43847ba40caac95, []int{34, 0}
+ return fileDescriptor_c43847ba40caac95, []int{36, 0}
}
func (m *PriorityCapabilities_PriorityRange) XXX_Unmarshal(b []byte) error {
@@ -2328,22 +2393,53 @@ func (m *PriorityCapabilities_PriorityRange) GetMaxPriority() int32 {
return 0
}
+type SymlinkAbsolutePathStrategy struct {
+ XXX_NoUnkeyedLiteral struct{} `json:"-"`
+ XXX_unrecognized []byte `json:"-"`
+ XXX_sizecache int32 `json:"-"`
+}
+
+func (m *SymlinkAbsolutePathStrategy) Reset() { *m = SymlinkAbsolutePathStrategy{} }
+func (m *SymlinkAbsolutePathStrategy) String() string { return proto.CompactTextString(m) }
+func (*SymlinkAbsolutePathStrategy) ProtoMessage() {}
+func (*SymlinkAbsolutePathStrategy) Descriptor() ([]byte, []int) {
+ return fileDescriptor_c43847ba40caac95, []int{37}
+}
+
+func (m *SymlinkAbsolutePathStrategy) XXX_Unmarshal(b []byte) error {
+ return xxx_messageInfo_SymlinkAbsolutePathStrategy.Unmarshal(m, b)
+}
+func (m *SymlinkAbsolutePathStrategy) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
+ return xxx_messageInfo_SymlinkAbsolutePathStrategy.Marshal(b, m, deterministic)
+}
+func (m *SymlinkAbsolutePathStrategy) XXX_Merge(src proto.Message) {
+ xxx_messageInfo_SymlinkAbsolutePathStrategy.Merge(m, src)
+}
+func (m *SymlinkAbsolutePathStrategy) XXX_Size() int {
+ return xxx_messageInfo_SymlinkAbsolutePathStrategy.Size(m)
+}
+func (m *SymlinkAbsolutePathStrategy) XXX_DiscardUnknown() {
+ xxx_messageInfo_SymlinkAbsolutePathStrategy.DiscardUnknown(m)
+}
+
+var xxx_messageInfo_SymlinkAbsolutePathStrategy proto.InternalMessageInfo
+
type CacheCapabilities struct {
- DigestFunction []DigestFunction `protobuf:"varint,1,rep,packed,name=digest_function,json=digestFunction,proto3,enum=build.bazel.remote.execution.v2.DigestFunction" json:"digest_function,omitempty"`
- ActionCacheUpdateCapabilities *ActionCacheUpdateCapabilities `protobuf:"bytes,2,opt,name=action_cache_update_capabilities,json=actionCacheUpdateCapabilities,proto3" json:"action_cache_update_capabilities,omitempty"`
- CachePriorityCapabilities *PriorityCapabilities `protobuf:"bytes,3,opt,name=cache_priority_capabilities,json=cachePriorityCapabilities,proto3" json:"cache_priority_capabilities,omitempty"`
- MaxBatchTotalSizeBytes int64 `protobuf:"varint,4,opt,name=max_batch_total_size_bytes,json=maxBatchTotalSizeBytes,proto3" json:"max_batch_total_size_bytes,omitempty"`
- SymlinkAbsolutePathStrategy CacheCapabilities_SymlinkAbsolutePathStrategy `protobuf:"varint,5,opt,name=symlink_absolute_path_strategy,json=symlinkAbsolutePathStrategy,proto3,enum=build.bazel.remote.execution.v2.CacheCapabilities_SymlinkAbsolutePathStrategy" json:"symlink_absolute_path_strategy,omitempty"`
- XXX_NoUnkeyedLiteral struct{} `json:"-"`
- XXX_unrecognized []byte `json:"-"`
- XXX_sizecache int32 `json:"-"`
+ DigestFunction []DigestFunction_Value `protobuf:"varint,1,rep,packed,name=digest_function,json=digestFunction,proto3,enum=build.bazel.remote.execution.v2.DigestFunction_Value" json:"digest_function,omitempty"`
+ ActionCacheUpdateCapabilities *ActionCacheUpdateCapabilities `protobuf:"bytes,2,opt,name=action_cache_update_capabilities,json=actionCacheUpdateCapabilities,proto3" json:"action_cache_update_capabilities,omitempty"`
+ CachePriorityCapabilities *PriorityCapabilities `protobuf:"bytes,3,opt,name=cache_priority_capabilities,json=cachePriorityCapabilities,proto3" json:"cache_priority_capabilities,omitempty"`
+ MaxBatchTotalSizeBytes int64 `protobuf:"varint,4,opt,name=max_batch_total_size_bytes,json=maxBatchTotalSizeBytes,proto3" json:"max_batch_total_size_bytes,omitempty"`
+ SymlinkAbsolutePathStrategy SymlinkAbsolutePathStrategy_Value `protobuf:"varint,5,opt,name=symlink_absolute_path_strategy,json=symlinkAbsolutePathStrategy,proto3,enum=build.bazel.remote.execution.v2.SymlinkAbsolutePathStrategy_Value" json:"symlink_absolute_path_strategy,omitempty"`
+ XXX_NoUnkeyedLiteral struct{} `json:"-"`
+ XXX_unrecognized []byte `json:"-"`
+ XXX_sizecache int32 `json:"-"`
}
func (m *CacheCapabilities) Reset() { *m = CacheCapabilities{} }
func (m *CacheCapabilities) String() string { return proto.CompactTextString(m) }
func (*CacheCapabilities) ProtoMessage() {}
func (*CacheCapabilities) Descriptor() ([]byte, []int) {
- return fileDescriptor_c43847ba40caac95, []int{35}
+ return fileDescriptor_c43847ba40caac95, []int{38}
}
func (m *CacheCapabilities) XXX_Unmarshal(b []byte) error {
@@ -2364,7 +2460,7 @@ func (m *CacheCapabilities) XXX_DiscardUnknown() {
var xxx_messageInfo_CacheCapabilities proto.InternalMessageInfo
-func (m *CacheCapabilities) GetDigestFunction() []DigestFunction {
+func (m *CacheCapabilities) GetDigestFunction() []DigestFunction_Value {
if m != nil {
return m.DigestFunction
}
@@ -2392,15 +2488,15 @@ func (m *CacheCapabilities) GetMaxBatchTotalSizeBytes() int64 {
return 0
}
-func (m *CacheCapabilities) GetSymlinkAbsolutePathStrategy() CacheCapabilities_SymlinkAbsolutePathStrategy {
+func (m *CacheCapabilities) GetSymlinkAbsolutePathStrategy() SymlinkAbsolutePathStrategy_Value {
if m != nil {
return m.SymlinkAbsolutePathStrategy
}
- return CacheCapabilities_UNKNOWN
+ return SymlinkAbsolutePathStrategy_UNKNOWN
}
type ExecutionCapabilities struct {
- DigestFunction DigestFunction `protobuf:"varint,1,opt,name=digest_function,json=digestFunction,proto3,enum=build.bazel.remote.execution.v2.DigestFunction" json:"digest_function,omitempty"`
+ DigestFunction DigestFunction_Value `protobuf:"varint,1,opt,name=digest_function,json=digestFunction,proto3,enum=build.bazel.remote.execution.v2.DigestFunction_Value" json:"digest_function,omitempty"`
ExecEnabled bool `protobuf:"varint,2,opt,name=exec_enabled,json=execEnabled,proto3" json:"exec_enabled,omitempty"`
ExecutionPriorityCapabilities *PriorityCapabilities `protobuf:"bytes,3,opt,name=execution_priority_capabilities,json=executionPriorityCapabilities,proto3" json:"execution_priority_capabilities,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
@@ -2412,7 +2508,7 @@ func (m *ExecutionCapabilities) Reset() { *m = ExecutionCapabilities{} }
func (m *ExecutionCapabilities) String() string { return proto.CompactTextString(m) }
func (*ExecutionCapabilities) ProtoMessage() {}
func (*ExecutionCapabilities) Descriptor() ([]byte, []int) {
- return fileDescriptor_c43847ba40caac95, []int{36}
+ return fileDescriptor_c43847ba40caac95, []int{39}
}
func (m *ExecutionCapabilities) XXX_Unmarshal(b []byte) error {
@@ -2433,7 +2529,7 @@ func (m *ExecutionCapabilities) XXX_DiscardUnknown() {
var xxx_messageInfo_ExecutionCapabilities proto.InternalMessageInfo
-func (m *ExecutionCapabilities) GetDigestFunction() DigestFunction {
+func (m *ExecutionCapabilities) GetDigestFunction() DigestFunction_Value {
if m != nil {
return m.DigestFunction
}
@@ -2466,7 +2562,7 @@ func (m *ToolDetails) Reset() { *m = ToolDetails{} }
func (m *ToolDetails) String() string { return proto.CompactTextString(m) }
func (*ToolDetails) ProtoMessage() {}
func (*ToolDetails) Descriptor() ([]byte, []int) {
- return fileDescriptor_c43847ba40caac95, []int{37}
+ return fileDescriptor_c43847ba40caac95, []int{40}
}
func (m *ToolDetails) XXX_Unmarshal(b []byte) error {
@@ -2515,7 +2611,7 @@ func (m *RequestMetadata) Reset() { *m = RequestMetadata{} }
func (m *RequestMetadata) String() string { return proto.CompactTextString(m) }
func (*RequestMetadata) ProtoMessage() {}
func (*RequestMetadata) Descriptor() ([]byte, []int) {
- return fileDescriptor_c43847ba40caac95, []int{38}
+ return fileDescriptor_c43847ba40caac95, []int{41}
}
func (m *RequestMetadata) XXX_Unmarshal(b []byte) error {
@@ -2565,9 +2661,9 @@ func (m *RequestMetadata) GetCorrelatedInvocationsId() string {
}
func init() {
- proto.RegisterEnum("build.bazel.remote.execution.v2.DigestFunction", DigestFunction_name, DigestFunction_value)
- proto.RegisterEnum("build.bazel.remote.execution.v2.ExecuteOperationMetadata_Stage", ExecuteOperationMetadata_Stage_name, ExecuteOperationMetadata_Stage_value)
- proto.RegisterEnum("build.bazel.remote.execution.v2.CacheCapabilities_SymlinkAbsolutePathStrategy", CacheCapabilities_SymlinkAbsolutePathStrategy_name, CacheCapabilities_SymlinkAbsolutePathStrategy_value)
+ proto.RegisterEnum("build.bazel.remote.execution.v2.ExecutionStage_Value", ExecutionStage_Value_name, ExecutionStage_Value_value)
+ proto.RegisterEnum("build.bazel.remote.execution.v2.DigestFunction_Value", DigestFunction_Value_name, DigestFunction_Value_value)
+ proto.RegisterEnum("build.bazel.remote.execution.v2.SymlinkAbsolutePathStrategy_Value", SymlinkAbsolutePathStrategy_Value_name, SymlinkAbsolutePathStrategy_Value_value)
proto.RegisterType((*Action)(nil), "build.bazel.remote.execution.v2.Action")
proto.RegisterType((*Command)(nil), "build.bazel.remote.execution.v2.Command")
proto.RegisterType((*Command_EnvironmentVariable)(nil), "build.bazel.remote.execution.v2.Command.EnvironmentVariable")
@@ -2590,6 +2686,7 @@ func init() {
proto.RegisterType((*LogFile)(nil), "build.bazel.remote.execution.v2.LogFile")
proto.RegisterType((*ExecuteResponse)(nil), "build.bazel.remote.execution.v2.ExecuteResponse")
proto.RegisterMapType((map[string]*LogFile)(nil), "build.bazel.remote.execution.v2.ExecuteResponse.ServerLogsEntry")
+ proto.RegisterType((*ExecutionStage)(nil), "build.bazel.remote.execution.v2.ExecutionStage")
proto.RegisterType((*ExecuteOperationMetadata)(nil), "build.bazel.remote.execution.v2.ExecuteOperationMetadata")
proto.RegisterType((*WaitExecutionRequest)(nil), "build.bazel.remote.execution.v2.WaitExecutionRequest")
proto.RegisterType((*GetActionResultRequest)(nil), "build.bazel.remote.execution.v2.GetActionResultRequest")
@@ -2607,9 +2704,11 @@ func init() {
proto.RegisterType((*GetTreeResponse)(nil), "build.bazel.remote.execution.v2.GetTreeResponse")
proto.RegisterType((*GetCapabilitiesRequest)(nil), "build.bazel.remote.execution.v2.GetCapabilitiesRequest")
proto.RegisterType((*ServerCapabilities)(nil), "build.bazel.remote.execution.v2.ServerCapabilities")
+ proto.RegisterType((*DigestFunction)(nil), "build.bazel.remote.execution.v2.DigestFunction")
proto.RegisterType((*ActionCacheUpdateCapabilities)(nil), "build.bazel.remote.execution.v2.ActionCacheUpdateCapabilities")
proto.RegisterType((*PriorityCapabilities)(nil), "build.bazel.remote.execution.v2.PriorityCapabilities")
proto.RegisterType((*PriorityCapabilities_PriorityRange)(nil), "build.bazel.remote.execution.v2.PriorityCapabilities.PriorityRange")
+ proto.RegisterType((*SymlinkAbsolutePathStrategy)(nil), "build.bazel.remote.execution.v2.SymlinkAbsolutePathStrategy")
proto.RegisterType((*CacheCapabilities)(nil), "build.bazel.remote.execution.v2.CacheCapabilities")
proto.RegisterType((*ExecutionCapabilities)(nil), "build.bazel.remote.execution.v2.ExecutionCapabilities")
proto.RegisterType((*ToolDetails)(nil), "build.bazel.remote.execution.v2.ToolDetails")
@@ -2621,203 +2720,204 @@ func init() {
}
var fileDescriptor_c43847ba40caac95 = []byte{
- // 3133 bytes of a gzipped FileDescriptorProto
- 0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xcc, 0x5a, 0x4b, 0x70, 0x1b, 0xc7,
- 0xd1, 0xfe, 0x17, 0x2f, 0x02, 0x0d, 0x90, 0x80, 0xc6, 0x14, 0x45, 0x41, 0x96, 0x25, 0xad, 0xcb,
- 0xfe, 0xf5, 0x53, 0x16, 0x20, 0x43, 0xbf, 0x65, 0x9b, 0x7e, 0x28, 0x7c, 0x40, 0x2f, 0x53, 0x14,
- 0xb3, 0x20, 0x65, 0x39, 0x71, 0xbc, 0x1e, 0x60, 0x87, 0xe0, 0x86, 0xc0, 0x2e, 0xb4, 0x3b, 0x20,
- 0x45, 0xb9, 0x54, 0xa9, 0x4a, 0x95, 0xe3, 0x8a, 0x53, 0xe5, 0x1c, 0x9c, 0x53, 0x72, 0x4a, 0x4e,
- 0xa9, 0x54, 0x8e, 0xb9, 0xa4, 0x92, 0x5c, 0x72, 0x4a, 0xae, 0x49, 0x55, 0x72, 0xcc, 0x25, 0x87,
- 0xa4, 0xca, 0xa7, 0x54, 0xe5, 0x96, 0x43, 0x6a, 0x1e, 0xfb, 0x02, 0x40, 0x2d, 0x40, 0xc9, 0xa9,
- 0x9c, 0xb0, 0xdb, 0xd3, 0xfd, 0x75, 0x4f, 0xcf, 0x74, 0xf7, 0x4c, 0x2f, 0xe0, 0x4a, 0xb3, 0x6f,
- 0x76, 0x8c, 0x6a, 0x13, 0x3f, 0x24, 0x9d, 0xaa, 0x43, 0xba, 0x36, 0x25, 0x55, 0xf2, 0x80, 0xb4,
- 0xfa, 0xd4, 0xb4, 0xad, 0xea, 0x5e, 0x4d, 0xd2, 0x74, 0x9f, 0x56, 0xe9, 0x39, 0x36, 0xb5, 0xd1,
- 0x19, 0x2e, 0x57, 0xe1, 0x72, 0x15, 0xc1, 0x53, 0x09, 0x78, 0xf6, 0x6a, 0xe5, 0x33, 0x61, 0x60,
- 0x97, 0x74, 0xf7, 0x88, 0x23, 0x7f, 0x04, 0x42, 0xf9, 0xd9, 0xb6, 0x6d, 0xb7, 0x3b, 0xa4, 0x8a,
- 0x7b, 0x66, 0x15, 0x5b, 0x96, 0x4d, 0x31, 0x13, 0x75, 0xe5, 0xe8, 0xf3, 0x72, 0xb4, 0x63, 0x5b,
- 0x6d, 0xa7, 0x6f, 0x59, 0xa6, 0xd5, 0xae, 0xda, 0x3d, 0xe2, 0x44, 0x98, 0x9e, 0x93, 0x4c, 0xfc,
- 0xad, 0xd9, 0xdf, 0xae, 0x1a, 0x7d, 0xc1, 0x20, 0xc7, 0xcf, 0x0c, 0x8e, 0x53, 0xb3, 0x4b, 0x5c,
- 0x8a, 0xbb, 0x3d, 0xc9, 0x70, 0x42, 0x32, 0x38, 0xbd, 0x56, 0xd5, 0xa5, 0x98, 0xf6, 0x25, 0xb2,
- 0xfa, 0x69, 0x02, 0x32, 0x4b, 0x2d, 0x06, 0x85, 0xd6, 0x61, 0xa6, 0x65, 0x77, 0xbb, 0xd8, 0x32,
- 0x74, 0xc3, 0x6c, 0x13, 0x97, 0xce, 0x2b, 0x67, 0x95, 0xf3, 0xf9, 0xda, 0xff, 0x56, 0x62, 0x5c,
- 0x50, 0x59, 0xe5, 0xec, 0xda, 0xb4, 0x14, 0x17, 0xaf, 0xa8, 0x01, 0xc7, 0x4c, 0xab, 0xd7, 0xa7,
- 0xba, 0x63, 0xdb, 0xd4, 0x83, 0x4c, 0x4c, 0x06, 0x59, 0xe4, 0x08, 0x9a, 0x6d, 0x53, 0x09, 0x7a,
- 0x19, 0xa6, 0xd8, 0xdc, 0xec, 0x3e, 0x9d, 0xcf, 0x70, 0xa8, 0x93, 0x15, 0x31, 0xb5, 0x8a, 0x37,
- 0xf7, 0xca, 0xaa, 0xf4, 0x8d, 0xe6, 0x71, 0xa2, 0xb3, 0x50, 0x30, 0x6c, 0xdd, 0xb2, 0xa9, 0xde,
- 0xc2, 0xad, 0x1d, 0x32, 0x3f, 0x75, 0x56, 0x39, 0x9f, 0xd5, 0xc0, 0xb0, 0xd7, 0x6d, 0xba, 0xc2,
- 0x28, 0xb7, 0x52, 0xd9, 0x64, 0x29, 0xa3, 0xfe, 0x38, 0x09, 0x53, 0x2b, 0x62, 0x0e, 0xe8, 0x59,
- 0xc8, 0x61, 0xa7, 0xdd, 0xef, 0x12, 0x8b, 0xba, 0xf3, 0xca, 0xd9, 0xe4, 0xf9, 0x9c, 0x16, 0x10,
- 0xd0, 0x7d, 0x38, 0x4e, 0xac, 0x3d, 0xd3, 0xb1, 0x2d, 0xf6, 0xae, 0xef, 0x61, 0xc7, 0xc4, 0xcd,
- 0x0e, 0x71, 0xe7, 0x13, 0x67, 0x93, 0xe7, 0xf3, 0xb5, 0x37, 0x63, 0xe7, 0x27, 0xd5, 0x54, 0xea,
- 0x01, 0xca, 0x5d, 0x09, 0xa2, 0xcd, 0x92, 0x61, 0xa2, 0x8b, 0xce, 0x41, 0xc1, 0xee, 0x53, 0xe6,
- 0xcf, 0x6d, 0x93, 0x69, 0x4a, 0x72, 0x9b, 0xf2, 0x82, 0x76, 0x8d, 0x91, 0xd0, 0x45, 0x40, 0x92,
- 0xc5, 0x30, 0x1d, 0xd2, 0xa2, 0xb6, 0x63, 0x12, 0x77, 0x3e, 0xc5, 0x19, 0x8f, 0x89, 0x91, 0xd5,
- 0x60, 0x00, 0xd5, 0x21, 0xdb, 0xeb, 0x60, 0xba, 0x6d, 0x3b, 0xdd, 0xf9, 0x34, 0x77, 0xe6, 0xff,
- 0xc5, 0xda, 0xbd, 0x21, 0x05, 0x34, 0x5f, 0x14, 0x5d, 0x80, 0x63, 0xfb, 0xb6, 0xb3, 0x6b, 0x5a,
- 0x6d, 0x5f, 0xed, 0x01, 0x5f, 0x9c, 0x9c, 0x56, 0x92, 0x03, 0x9e, 0xd6, 0x83, 0xf2, 0x55, 0x78,
- 0x66, 0xc4, 0x94, 0x11, 0x82, 0x94, 0x85, 0xbb, 0x84, 0xef, 0xb8, 0x9c, 0xc6, 0x9f, 0xd1, 0x2c,
- 0xa4, 0xf7, 0x70, 0xa7, 0x4f, 0xf8, 0x9e, 0xc9, 0x69, 0xe2, 0x45, 0xfd, 0x81, 0x02, 0x59, 0xcf,
- 0x08, 0xa4, 0x01, 0xf4, 0x1c, 0x16, 0x2d, 0x94, 0x4d, 0x54, 0xe1, 0xbe, 0xaf, 0x8d, 0x3d, 0x87,
- 0xca, 0x86, 0x90, 0x3d, 0xd0, 0x42, 0x28, 0xe5, 0xff, 0x87, 0xac, 0x47, 0x9f, 0xc0, 0xac, 0xbf,
- 0x29, 0x90, 0xf3, 0x67, 0x89, 0xae, 0x42, 0x5a, 0x2c, 0x92, 0x30, 0x29, 0xde, 0xad, 0x6c, 0xfd,
- 0xd6, 0x6d, 0x83, 0x68, 0x42, 0x0e, 0x6d, 0x40, 0x3e, 0xbc, 0x84, 0x62, 0x57, 0x55, 0xc6, 0x88,
- 0x1a, 0x69, 0x01, 0xc7, 0x0a, 0x43, 0xa0, 0x1b, 0x90, 0x75, 0x0f, 0xba, 0x1d, 0xd3, 0xda, 0x15,
- 0x5b, 0x27, 0x5f, 0x7b, 0x29, 0x16, 0xae, 0x21, 0x04, 0x38, 0x98, 0x2f, 0xad, 0x7e, 0xaa, 0x40,
- 0xd6, 0xb3, 0x77, 0xa4, 0x87, 0xae, 0x42, 0xe6, 0x68, 0xd1, 0x2e, 0xc5, 0xd0, 0xf3, 0x30, 0x6d,
- 0xba, 0x32, 0x13, 0xb3, 0xed, 0x31, 0x9f, 0xe2, 0x01, 0x5b, 0x30, 0xdd, 0xba, 0x4f, 0xe3, 0x21,
- 0x9b, 0x52, 0x0d, 0x98, 0x8e, 0x4c, 0xfa, 0x4b, 0x31, 0x48, 0x7d, 0x1d, 0xf2, 0x21, 0x5f, 0x8c,
- 0xd4, 0x31, 0x07, 0x19, 0x8a, 0x9d, 0x36, 0xa1, 0x72, 0x5f, 0xc8, 0x37, 0xf5, 0x0d, 0xc8, 0xc8,
- 0xd4, 0x85, 0x20, 0xb5, 0x83, 0xdd, 0x1d, 0x4f, 0x8a, 0x3d, 0xa3, 0xd3, 0x00, 0xae, 0xf9, 0x90,
- 0xe8, 0xcd, 0x03, 0xca, 0x97, 0x59, 0x39, 0x9f, 0xd4, 0x72, 0x8c, 0xb2, 0xcc, 0x08, 0xea, 0x5f,
- 0x32, 0x30, 0x27, 0xa6, 0x4c, 0x0c, 0x91, 0xa5, 0x6f, 0x13, 0x8a, 0x0d, 0x4c, 0x31, 0xd3, 0xc7,
- 0x82, 0x8b, 0x38, 0x12, 0x4f, 0xbe, 0xa1, 0x3a, 0x94, 0xee, 0xf7, 0x49, 0x9f, 0x18, 0xba, 0x5f,
- 0x03, 0xe4, 0xac, 0xcb, 0x43, 0x99, 0x72, 0xd3, 0xe3, 0xd0, 0x8a, 0x42, 0xc6, 0x27, 0xa0, 0x0d,
- 0x98, 0x13, 0x80, 0xba, 0x4b, 0xb1, 0x43, 0x43, 0x60, 0xc9, 0x58, 0xb0, 0x59, 0x21, 0xd9, 0x60,
- 0x82, 0x01, 0xe2, 0x3d, 0x28, 0x4b, 0xc4, 0x96, 0xdd, 0xed, 0x75, 0x08, 0x8d, 0x98, 0x98, 0x8a,
- 0x45, 0x9d, 0x17, 0xd2, 0x2b, 0x9e, 0x70, 0x80, 0xfc, 0x1e, 0x9c, 0x12, 0x85, 0x66, 0x9b, 0xd0,
- 0xd6, 0xce, 0x90, 0xc1, 0xe9, 0x78, 0x68, 0x2e, 0x7e, 0x8d, 0x49, 0x0f, 0x18, 0x8d, 0xe1, 0x4c,
- 0x18, 0x7a, 0x94, 0xe5, 0x99, 0x58, 0xf8, 0x67, 0x03, 0xf8, 0x11, 0xd6, 0xdf, 0x85, 0x93, 0xfe,
- 0xd6, 0x1b, 0xb2, 0x7d, 0x2a, 0x16, 0xfc, 0x84, 0x2f, 0x3c, 0x60, 0xfa, 0x07, 0x70, 0x3a, 0xc0,
- 0x1d, 0x65, 0x78, 0x36, 0x16, 0xfb, 0x94, 0x0f, 0x30, 0xc2, 0xee, 0x6f, 0xc0, 0x69, 0x59, 0x6c,
- 0xfa, 0xbd, 0x8e, 0x8d, 0x8d, 0x21, 0xdb, 0x73, 0xb1, 0xf8, 0x65, 0x01, 0xb0, 0xc5, 0xe5, 0x07,
- 0xcc, 0x27, 0x70, 0x2e, 0x0a, 0x3f, 0x6a, 0x0a, 0x10, 0xab, 0xe2, 0xb9, 0xb0, 0x8a, 0xe1, 0x59,
- 0xa8, 0xff, 0x48, 0x43, 0x41, 0x44, 0x96, 0x46, 0xdc, 0x7e, 0x87, 0xa2, 0xf5, 0x81, 0x32, 0x2b,
- 0x52, 0xef, 0x85, 0xd8, 0x8c, 0x71, 0xc7, 0xaf, 0xc3, 0xd1, 0x9a, 0xfc, 0x21, 0xcc, 0x86, 0xf0,
- 0x74, 0x3f, 0x07, 0xc3, 0x98, 0x29, 0x5d, 0xe0, 0xca, 0xec, 0xa3, 0xa1, 0x00, 0x5a, 0x92, 0x5c,
- 0xa4, 0x8f, 0xac, 0xfa, 0x22, 0xc7, 0x5f, 0x1a, 0x13, 0xdf, 0xcf, 0xa1, 0xa3, 0xce, 0x09, 0xdf,
- 0x84, 0x93, 0x03, 0x0a, 0x0e, 0x82, 0x79, 0xe4, 0x8f, 0x34, 0x8f, 0x13, 0x51, 0x2d, 0x07, 0xfe,
- 0x64, 0x4e, 0x41, 0x8e, 0x3c, 0x30, 0xa9, 0xde, 0xb2, 0x0d, 0x91, 0xf6, 0xd3, 0x5a, 0x96, 0x11,
- 0x56, 0x58, 0xde, 0x65, 0xd9, 0x92, 0x1a, 0x36, 0x3b, 0x52, 0xe2, 0x7d, 0x1e, 0xd7, 0x05, 0x2d,
- 0x27, 0x28, 0x1a, 0xde, 0x47, 0x6b, 0x30, 0x2d, 0x87, 0x65, 0xb6, 0xcf, 0x4c, 0x96, 0xed, 0x0b,
- 0x42, 0x5a, 0xa6, 0x6b, 0xa1, 0x8c, 0x38, 0x0e, 0x57, 0x36, 0xe5, 0x2b, 0x23, 0x8e, 0x13, 0x28,
- 0x63, 0xc3, 0x52, 0x59, 0x76, 0x72, 0x65, 0xc4, 0x71, 0xa4, 0xb2, 0x6d, 0x40, 0x41, 0xb0, 0x76,
- 0x65, 0x8e, 0x97, 0x11, 0xf4, 0x6a, 0x2c, 0xe4, 0xe8, 0x12, 0xa1, 0x1d, 0xf3, 0x99, 0x3c, 0xd2,
- 0xad, 0x54, 0x56, 0x29, 0x25, 0xd4, 0x9f, 0x2a, 0x00, 0xc1, 0x7e, 0x65, 0x85, 0xa9, 0x87, 0xa9,
- 0x5f, 0x98, 0xd8, 0xf3, 0x7f, 0xa6, 0x86, 0xa3, 0x32, 0x64, 0x5b, 0xb6, 0x45, 0xf9, 0x19, 0x5b,
- 0x2c, 0xa7, 0xff, 0x2e, 0xeb, 0xfb, 0x67, 0x0a, 0xa4, 0x36, 0x1d, 0x42, 0xd0, 0xdb, 0x90, 0x62,
- 0xf7, 0x08, 0x79, 0x27, 0x59, 0x18, 0xff, 0x28, 0xa4, 0x71, 0x39, 0x74, 0x0d, 0xb2, 0xad, 0x1d,
- 0xb3, 0x63, 0x38, 0xc4, 0x92, 0x31, 0x3d, 0x09, 0x86, 0x2f, 0xab, 0xf6, 0xa1, 0x38, 0x10, 0x32,
- 0x23, 0xfd, 0x77, 0x03, 0xf2, 0xd4, 0x21, 0xc4, 0xdb, 0x1c, 0xc9, 0xc9, 0x9c, 0x08, 0x4c, 0x56,
- 0x3c, 0xdf, 0x4a, 0x65, 0x13, 0xa5, 0xa4, 0xfa, 0x06, 0x4c, 0x47, 0x22, 0x68, 0xa4, 0xd2, 0xc3,
- 0xce, 0x20, 0x17, 0xa1, 0x58, 0xf7, 0xb4, 0x6c, 0xd8, 0x1d, 0xb3, 0x75, 0xc0, 0x3c, 0xdf, 0x73,
- 0x4c, 0xdb, 0x31, 0xe9, 0x01, 0x87, 0x48, 0x6b, 0xfe, 0xbb, 0x7a, 0x09, 0x90, 0x48, 0x86, 0x2e,
- 0xbf, 0x1c, 0x8d, 0x21, 0xf1, 0x71, 0x12, 0x66, 0xe4, 0x26, 0xd4, 0xc8, 0xfd, 0xbe, 0xb7, 0xfe,
- 0x96, 0x4b, 0xb1, 0xd5, 0x22, 0x7a, 0xe8, 0xb0, 0x54, 0xf0, 0x88, 0xeb, 0xec, 0xd0, 0xb4, 0x00,
- 0xc7, 0xdc, 0x5d, 0xb3, 0x27, 0xae, 0x65, 0x7a, 0xc7, 0xb6, 0x77, 0xfb, 0xe2, 0x80, 0x91, 0xd5,
- 0x8a, 0x6c, 0x80, 0xeb, 0x5f, 0xe3, 0x64, 0x16, 0x70, 0x98, 0xef, 0xef, 0xa3, 0x46, 0xb7, 0x90,
- 0x96, 0x01, 0xf7, 0x75, 0x28, 0x05, 0x01, 0xd7, 0xe3, 0x33, 0x94, 0xc5, 0xf6, 0xd2, 0x98, 0xe1,
- 0xe6, 0xfb, 0x52, 0x2b, 0x92, 0x01, 0xe7, 0x12, 0x98, 0x75, 0x84, 0x03, 0xe5, 0xcc, 0xa4, 0x02,
- 0x91, 0x22, 0x2e, 0xc7, 0x2a, 0x18, 0xf6, 0xbe, 0x86, 0x9c, 0x21, 0x9a, 0xd8, 0x19, 0xb7, 0x52,
- 0xd9, 0x54, 0x29, 0x7d, 0x2b, 0x95, 0x4d, 0x97, 0x32, 0xea, 0x7d, 0x98, 0x5a, 0xb3, 0xdb, 0x3c,
- 0xa8, 0x83, 0x00, 0x56, 0x8e, 0x16, 0xc0, 0x2f, 0xc0, 0xcc, 0x4e, 0xbf, 0x8b, 0x2d, 0xdd, 0x21,
- 0xd8, 0xe0, 0x11, 0x9c, 0xe0, 0x0b, 0x33, 0xcd, 0xa9, 0x9a, 0x24, 0xaa, 0xdf, 0x4f, 0x7a, 0x9b,
- 0x8b, 0x68, 0xc4, 0xed, 0xd9, 0x96, 0x4b, 0x50, 0x1d, 0x32, 0xc2, 0x5c, 0xa9, 0xfb, 0x62, 0xac,
- 0xee, 0x70, 0x09, 0xd6, 0xa4, 0x30, 0xdb, 0x42, 0xdc, 0x7d, 0x86, 0x2e, 0xd1, 0x84, 0x01, 0x05,
- 0x41, 0x94, 0xf5, 0x7a, 0x01, 0x32, 0xa2, 0xa1, 0x21, 0x63, 0x0c, 0x79, 0x87, 0x01, 0xa7, 0xd7,
- 0xaa, 0x34, 0xf8, 0x88, 0x26, 0x39, 0x10, 0x86, 0xbc, 0x4b, 0x9c, 0x3d, 0xe2, 0xe8, 0x1d, 0xbb,
- 0x2d, 0x2e, 0xc6, 0xf9, 0xda, 0x57, 0xc6, 0x4d, 0xaf, 0xde, 0xf4, 0x2a, 0x0d, 0x8e, 0xb1, 0x66,
- 0xb7, 0xdd, 0xba, 0x45, 0x9d, 0x03, 0x0d, 0x5c, 0x9f, 0x80, 0xe6, 0x61, 0xaa, 0x4b, 0x5c, 0x17,
- 0xb7, 0x09, 0x4f, 0x68, 0x39, 0xcd, 0x7b, 0x2d, 0xb7, 0xa1, 0x38, 0x20, 0x88, 0x4a, 0x90, 0xdc,
- 0x25, 0x07, 0x32, 0x32, 0xd8, 0x23, 0x7a, 0x3b, 0x7c, 0xb9, 0xcc, 0xd7, 0xce, 0xc7, 0xda, 0x26,
- 0x97, 0x5b, 0x5e, 0x43, 0x17, 0x13, 0xaf, 0x29, 0xea, 0x17, 0x09, 0x98, 0x97, 0x26, 0xdf, 0xf1,
- 0x1a, 0x49, 0xfe, 0xb5, 0x61, 0x0b, 0xd2, 0x2e, 0x65, 0xd6, 0x31, 0xa5, 0x33, 0xb5, 0xab, 0xe3,
- 0x4e, 0x7e, 0x08, 0x89, 0xf9, 0xb6, 0x4d, 0x34, 0x81, 0x36, 0x1c, 0x9c, 0x89, 0x27, 0x09, 0xce,
- 0x97, 0x00, 0xc9, 0x42, 0xee, 0x52, 0x87, 0xe0, 0xae, 0x48, 0x20, 0x49, 0xd1, 0x52, 0x10, 0x23,
- 0x0d, 0x3e, 0xc0, 0x93, 0x88, 0xe0, 0x66, 0x95, 0x38, 0xcc, 0x9d, 0xf2, 0xb9, 0x89, 0xe3, 0x04,
- 0xdc, 0xea, 0x1d, 0x48, 0x73, 0xcb, 0x51, 0x1e, 0xa6, 0xb6, 0xd6, 0xdf, 0x59, 0xbf, 0xf3, 0xee,
- 0x7a, 0xe9, 0x7f, 0x50, 0x11, 0xf2, 0x2b, 0x4b, 0x2b, 0x37, 0xea, 0xfa, 0xca, 0x8d, 0xfa, 0xca,
- 0x3b, 0x25, 0x05, 0x01, 0x64, 0xbe, 0xba, 0x55, 0xdf, 0xaa, 0xaf, 0x96, 0x12, 0x68, 0x1a, 0x72,
- 0xf5, 0x7b, 0xf5, 0x95, 0xad, 0xcd, 0x9b, 0xeb, 0xd7, 0x4b, 0x49, 0xf6, 0xba, 0x72, 0xe7, 0xf6,
- 0xc6, 0x5a, 0x7d, 0xb3, 0xbe, 0x5a, 0x4a, 0xa9, 0x0b, 0x30, 0xfb, 0x2e, 0x36, 0xa9, 0x9f, 0x14,
- 0xbc, 0x04, 0x38, 0xe2, 0x92, 0xa8, 0x7e, 0x9c, 0x80, 0xb9, 0xeb, 0x84, 0x46, 0x76, 0xfb, 0x24,
- 0xf9, 0xf2, 0xe9, 0xba, 0x99, 0xab, 0xec, 0x98, 0x16, 0xd1, 0x85, 0x4f, 0x65, 0xe6, 0x2d, 0x08,
- 0x62, 0x83, 0xd3, 0xa2, 0x4c, 0xc4, 0x71, 0xfc, 0x3a, 0xee, 0x31, 0x11, 0xc7, 0x41, 0x15, 0x78,
- 0x46, 0x32, 0x45, 0xce, 0xce, 0x69, 0xd1, 0x79, 0x12, 0x43, 0xc1, 0x81, 0xc3, 0x55, 0x7f, 0x9f,
- 0x80, 0x93, 0x5b, 0x3d, 0x03, 0x53, 0xf2, 0x5f, 0xe2, 0x0a, 0xcd, 0x47, 0x93, 0xa9, 0x26, 0x79,
- 0x94, 0xc4, 0x25, 0x31, 0x65, 0x66, 0x3a, 0xac, 0x0a, 0xa4, 0x9e, 0x6a, 0x15, 0x50, 0x3f, 0x55,
- 0xe0, 0xc4, 0x35, 0xd3, 0x32, 0x6e, 0x9b, 0xae, 0x6b, 0x5a, 0xed, 0xe5, 0x8e, 0xdd, 0x74, 0x27,
- 0xf2, 0xe4, 0x2d, 0x28, 0x34, 0x3b, 0x76, 0x53, 0xfa, 0xd1, 0xbb, 0xf1, 0x8c, 0xed, 0xc8, 0x3c,
- 0x13, 0x16, 0xcf, 0xae, 0xda, 0x87, 0xf9, 0x61, 0x5b, 0x64, 0x55, 0x78, 0x0f, 0x66, 0xbb, 0x82,
- 0xae, 0x3f, 0x89, 0x3e, 0xd4, 0x0d, 0xc0, 0x3d, 0xb5, 0xff, 0x52, 0xe0, 0xc4, 0x32, 0xa6, 0xad,
- 0x1d, 0xb1, 0xa9, 0x26, 0xf7, 0xc1, 0xfb, 0x90, 0x75, 0x04, 0xbf, 0x67, 0x4f, 0x7c, 0x59, 0x38,
- 0x44, 0x61, 0x45, 0xfe, 0x6a, 0x3e, 0x62, 0xf9, 0x03, 0x98, 0xf2, 0xac, 0x79, 0xe2, 0xb2, 0x8c,
- 0x20, 0xc5, 0xef, 0x06, 0x09, 0x7e, 0x5c, 0xe6, 0xcf, 0xea, 0x3f, 0x15, 0x98, 0x1f, 0xb6, 0x46,
- 0xba, 0xfd, 0x43, 0xc8, 0x39, 0xf2, 0xd9, 0xeb, 0x47, 0x2e, 0x1f, 0x61, 0x6e, 0xb2, 0xf6, 0x79,
- 0x0f, 0x5a, 0x00, 0x5a, 0xde, 0x87, 0xac, 0xaf, 0xed, 0x89, 0xe7, 0x17, 0xd4, 0xf3, 0x44, 0x5c,
- 0x3d, 0x57, 0xbf, 0x05, 0xc7, 0xb9, 0xa1, 0xec, 0x30, 0x32, 0xf9, 0x9a, 0x2f, 0xc1, 0xd4, 0x11,
- 0xb7, 0xa0, 0x27, 0xa7, 0x7e, 0x27, 0x01, 0x73, 0x83, 0x16, 0x48, 0x47, 0x7c, 0x30, 0xec, 0xf6,
- 0x31, 0xb7, 0xd4, 0x10, 0xd6, 0x48, 0xa7, 0x7f, 0x4f, 0x79, 0x9a, 0x5e, 0x1f, 0xb1, 0xab, 0x26,
- 0x39, 0x59, 0xa9, 0xbf, 0x52, 0x60, 0xe6, 0x3a, 0xa1, 0xec, 0xa6, 0x36, 0xd1, 0x1a, 0xdc, 0x80,
- 0xfc, 0x13, 0x7c, 0x1d, 0x02, 0x27, 0xf8, 0x30, 0x74, 0x0a, 0x72, 0x3d, 0xdc, 0x26, 0xba, 0x6b,
- 0x3e, 0x14, 0x47, 0x05, 0x76, 0x3f, 0xc1, 0x6d, 0xd2, 0x30, 0x1f, 0xf2, 0xc6, 0x01, 0x1f, 0xa4,
- 0xf6, 0x2e, 0xb1, 0xe4, 0xd1, 0x80, 0xb3, 0x6f, 0x32, 0x82, 0xfa, 0x89, 0x02, 0x45, 0xdf, 0x7a,
- 0xe9, 0xd2, 0xb5, 0x68, 0x07, 0x5e, 0x99, 0xf8, 0xca, 0x18, 0xe9, 0xbe, 0xbf, 0x08, 0x45, 0x8b,
- 0x3c, 0xa0, 0x7a, 0xc8, 0x0a, 0x71, 0x45, 0x9b, 0x66, 0xe4, 0x0d, 0xdf, 0x92, 0xb7, 0xf8, 0xf9,
- 0x60, 0x05, 0xf7, 0x70, 0xd3, 0xec, 0x98, 0xd4, 0x24, 0x13, 0x6d, 0x69, 0xf5, 0xb7, 0x49, 0x40,
- 0xe2, 0x90, 0x19, 0x86, 0x40, 0x18, 0x90, 0xa8, 0x40, 0xad, 0x10, 0x55, 0x6e, 0x95, 0xf8, 0xcf,
- 0x25, 0xbc, 0xd8, 0x44, 0x4c, 0x3a, 0xd6, 0x1a, 0x24, 0xa1, 0x2e, 0xcc, 0x85, 0xba, 0x8d, 0x61,
- 0x35, 0x62, 0x4d, 0xaf, 0x8c, 0x7f, 0xab, 0x8a, 0xa8, 0x3a, 0x4e, 0x46, 0x91, 0xd1, 0x06, 0xcc,
- 0x19, 0xa4, 0xe7, 0x90, 0x16, 0xa6, 0xc4, 0xd0, 0x71, 0xcf, 0xd4, 0xf7, 0x88, 0xe3, 0x9a, 0xb6,
- 0xe5, 0xb7, 0xa7, 0xc3, 0xea, 0xe4, 0xe7, 0xd8, 0x06, 0xe9, 0xde, 0x25, 0x8e, 0x36, 0x1b, 0x48,
- 0x2e, 0xf5, 0xcc, 0xbb, 0x42, 0x0e, 0x2d, 0x43, 0xb1, 0x63, 0xef, 0x47, 0xa0, 0x52, 0xb1, 0x50,
- 0xd3, 0x1d, 0x7b, 0x3f, 0x84, 0xb1, 0x0a, 0xa5, 0x1d, 0xb3, 0xbd, 0x13, 0x01, 0x49, 0xc7, 0x82,
- 0xcc, 0x30, 0x99, 0x00, 0x45, 0xbd, 0x06, 0xa7, 0xc5, 0xa9, 0x82, 0x3b, 0x5e, 0x24, 0xe1, 0xc8,
- 0xe4, 0x5f, 0x80, 0x99, 0x3e, 0xa7, 0xea, 0xc4, 0x62, 0x77, 0x30, 0x83, 0x2f, 0x65, 0x56, 0x9b,
- 0x16, 0xd4, 0xba, 0x20, 0xaa, 0x7f, 0x50, 0x60, 0x76, 0x43, 0xde, 0xd0, 0x23, 0xf2, 0x2d, 0x00,
- 0x79, 0x73, 0x0f, 0x76, 0xf6, 0x4a, 0xfc, 0x57, 0xb3, 0x11, 0x50, 0x3e, 0x51, 0xc3, 0x56, 0x9b,
- 0x68, 0x21, 0xd8, 0xf2, 0x16, 0x4c, 0x47, 0x06, 0xd1, 0x39, 0x28, 0x74, 0x4d, 0x4b, 0x1f, 0xe8,
- 0x21, 0xe4, 0xbb, 0xa6, 0xe5, 0xf1, 0x71, 0x16, 0xfc, 0x20, 0x60, 0x49, 0x48, 0x16, 0xfc, 0xc0,
- 0x63, 0x51, 0xbf, 0x9b, 0x86, 0x63, 0x43, 0x1b, 0x12, 0xdd, 0x83, 0xa2, 0xc8, 0x20, 0xfa, 0x76,
- 0xdf, 0xe2, 0xbe, 0xe3, 0xd3, 0x9a, 0xa9, 0x55, 0xc7, 0x4c, 0x25, 0xd7, 0xa4, 0x98, 0x36, 0x63,
- 0x44, 0xde, 0xd1, 0x27, 0x0a, 0x9c, 0x95, 0x27, 0x43, 0x11, 0x42, 0xd2, 0xf3, 0x23, 0xb6, 0xf8,
- 0xdb, 0x63, 0x1e, 0x16, 0x0f, 0x59, 0x56, 0xed, 0x34, 0x7e, 0xec, 0xaa, 0xf7, 0xe1, 0x94, 0x3c,
- 0x46, 0x4a, 0x5f, 0x44, 0x6d, 0x10, 0xfb, 0xfe, 0x95, 0x23, 0x2d, 0xa3, 0x76, 0x92, 0x23, 0x8f,
- 0xdc, 0x2c, 0x8b, 0x50, 0x66, 0x6b, 0xd2, 0x64, 0x95, 0x49, 0xa7, 0x36, 0xc5, 0x1d, 0x3d, 0xf4,
- 0xc5, 0x2a, 0xc5, 0xbf, 0x58, 0xcd, 0x75, 0xf1, 0x03, 0x5e, 0xba, 0x36, 0xd9, 0x78, 0xc3, 0xfb,
- 0x7c, 0x85, 0x3e, 0x57, 0xe0, 0x39, 0xd9, 0x28, 0xd6, 0x71, 0xd3, 0xb5, 0x3b, 0x7d, 0x4a, 0xf4,
- 0x1e, 0xa6, 0x3b, 0xec, 0xa6, 0x86, 0x29, 0x69, 0x1f, 0xf0, 0xf0, 0x98, 0xa9, 0xad, 0x4f, 0x9e,
- 0x84, 0xbc, 0x8f, 0x93, 0x4b, 0x12, 0x77, 0x03, 0xd3, 0x9d, 0x86, 0x44, 0xd5, 0x4e, 0xb9, 0x87,
- 0x0f, 0xaa, 0xd7, 0xe1, 0xd4, 0x63, 0x64, 0xa3, 0xf7, 0xc2, 0x19, 0x80, 0xd5, 0x9b, 0x8d, 0xa5,
- 0xb5, 0xb5, 0x3b, 0xef, 0xd6, 0x57, 0x4b, 0x0a, 0x1b, 0xf4, 0x5e, 0x12, 0xea, 0xe7, 0x09, 0x38,
- 0x3e, 0x32, 0x6b, 0x8d, 0xde, 0x8f, 0xca, 0xd3, 0xd8, 0x8f, 0xe7, 0xa0, 0xc0, 0xd8, 0xfd, 0xc8,
- 0x17, 0x2d, 0x91, 0x3c, 0xa3, 0xc9, 0xb8, 0x47, 0x8f, 0xe0, 0x4c, 0xa8, 0xb5, 0xf5, 0xf4, 0x37,
- 0x4b, 0xf0, 0x59, 0x69, 0xd4, 0xb0, 0x7a, 0x1b, 0xf2, 0x9b, 0xb6, 0xdd, 0x59, 0x25, 0x14, 0x9b,
- 0x1d, 0xde, 0xd0, 0xa7, 0xb6, 0xdd, 0x09, 0xd7, 0xac, 0x2c, 0x23, 0xf0, 0xf2, 0x7f, 0x0e, 0x0a,
- 0x7c, 0xd0, 0x4b, 0x96, 0xa2, 0x26, 0xe6, 0x19, 0xcd, 0xcb, 0x86, 0x7f, 0x57, 0xa0, 0x28, 0x6b,
- 0xa0, 0xdf, 0xc4, 0xb8, 0x23, 0xc5, 0x0c, 0xa1, 0x43, 0x56, 0xb2, 0xf8, 0xef, 0xd9, 0x21, 0xbb,
- 0x84, 0x92, 0x90, 0x91, 0x32, 0xc8, 0x4d, 0x43, 0x1a, 0x91, 0x15, 0x84, 0x9b, 0x06, 0x7a, 0x09,
- 0x10, 0xd7, 0x66, 0x5a, 0x7b, 0x76, 0x0b, 0x7b, 0x5c, 0xb2, 0x1b, 0xc1, 0x46, 0x6e, 0xfa, 0x03,
- 0x37, 0x0d, 0xb4, 0x08, 0x27, 0x5b, 0xb6, 0xe3, 0x90, 0x0e, 0xaf, 0x4c, 0x81, 0x8c, 0xcb, 0x84,
- 0xc4, 0xc9, 0xe3, 0x44, 0xc0, 0x10, 0x88, 0xba, 0x37, 0x8d, 0x85, 0x37, 0x61, 0x26, 0xba, 0xfc,
- 0xd1, 0xcd, 0x08, 0x90, 0x69, 0xdc, 0x58, 0xaa, 0xbd, 0x72, 0xa5, 0xa4, 0xa0, 0x2c, 0xa4, 0x1a,
- 0x37, 0x96, 0x5e, 0x2e, 0x25, 0xd0, 0x14, 0x24, 0x6f, 0xaf, 0xbe, 0x52, 0x4a, 0xd6, 0x7e, 0x99,
- 0x80, 0x9c, 0xbf, 0x1d, 0xd1, 0x67, 0x0a, 0x4c, 0xc9, 0xde, 0x0d, 0xaa, 0x8e, 0xdf, 0xe2, 0xe2,
- 0x8e, 0x2e, 0x9f, 0xf6, 0x8e, 0x7a, 0xa1, 0x7f, 0x25, 0x55, 0xfc, 0x16, 0x90, 0xfa, 0xf2, 0xb7,
- 0xff, 0xf8, 0xd7, 0xcf, 0x13, 0x17, 0xd4, 0x17, 0xab, 0x7b, 0xb5, 0xea, 0x47, 0x91, 0x63, 0xc9,
- 0x5b, 0x0b, 0x0b, 0x8f, 0xaa, 0xc2, 0x75, 0xee, 0xa2, 0x50, 0x41, 0x16, 0x95, 0x85, 0x4b, 0x0a,
- 0xfa, 0xa1, 0x02, 0xd3, 0x91, 0x46, 0x09, 0x8a, 0xdf, 0x7f, 0xa3, 0x1a, 0x2b, 0x93, 0x19, 0xc7,
- 0x6d, 0x0a, 0xfe, 0x4f, 0x55, 0x5d, 0x58, 0x78, 0xb4, 0xb8, 0x1f, 0x46, 0xe5, 0xc6, 0xd5, 0xfe,
- 0x94, 0x84, 0x7c, 0x28, 0x3b, 0xa3, 0x3f, 0x8b, 0x13, 0x61, 0xe4, 0xcb, 0x60, 0xfc, 0x77, 0x98,
- 0xd1, 0xad, 0x9d, 0xf2, 0x64, 0x5d, 0x04, 0xf5, 0x7d, 0x3e, 0x81, 0xbb, 0x68, 0xf3, 0xb1, 0xde,
- 0x95, 0xdd, 0x81, 0xea, 0x47, 0x91, 0x2e, 0x48, 0x65, 0x07, 0xbb, 0x3b, 0x8f, 0x06, 0x89, 0x41,
- 0xc2, 0x7e, 0x84, 0xbe, 0x50, 0x00, 0x0d, 0xb7, 0x5e, 0xd0, 0x62, 0xac, 0x8d, 0x87, 0xf6, 0x6b,
- 0x26, 0x9d, 0xdf, 0x2e, 0x9f, 0x1f, 0x29, 0x7f, 0x29, 0xf3, 0x5b, 0x8c, 0xf6, 0x71, 0x6a, 0x3f,
- 0xca, 0xc0, 0xc9, 0x15, 0xf1, 0x49, 0x69, 0xc9, 0x30, 0x1c, 0xe2, 0xba, 0x2c, 0x49, 0x36, 0xa8,
- 0xed, 0xe0, 0x36, 0x41, 0xbf, 0x56, 0xa0, 0x34, 0xd8, 0xaf, 0x40, 0xaf, 0x8d, 0xf1, 0x6f, 0x9d,
- 0x91, 0xed, 0x96, 0xf2, 0xeb, 0x47, 0x90, 0x14, 0xd7, 0x0d, 0xf5, 0x32, 0x77, 0xca, 0x45, 0xf5,
- 0xfc, 0x21, 0x4e, 0x69, 0x32, 0xee, 0xc5, 0xed, 0x40, 0x7c, 0x51, 0x59, 0xe0, 0xe6, 0x0f, 0xde,
- 0xd4, 0xc7, 0x30, 0xff, 0x90, 0xc6, 0xc5, 0x18, 0xe6, 0x1f, 0xd6, 0x16, 0x18, 0xd3, 0xfc, 0x66,
- 0x20, 0xce, 0xcc, 0xff, 0x85, 0x02, 0x33, 0xd1, 0x1b, 0x2f, 0xba, 0x32, 0xf1, 0x15, 0x59, 0x98,
- 0xfe, 0xea, 0x11, 0xaf, 0xd6, 0xb1, 0xa9, 0x2c, 0x64, 0x38, 0x13, 0x66, 0x66, 0xff, 0x4e, 0x81,
- 0x29, 0x79, 0x5b, 0x1c, 0x23, 0xb3, 0x46, 0x6f, 0xc5, 0xe5, 0x4b, 0xe3, 0x0b, 0x48, 0x0b, 0xef,
- 0x71, 0x0b, 0x35, 0xb4, 0xf1, 0x38, 0x0b, 0xab, 0x1f, 0x85, 0xae, 0xd1, 0x5e, 0x90, 0x84, 0x49,
- 0xe1, 0x10, 0x69, 0x0b, 0x0d, 0x97, 0x94, 0xda, 0x6f, 0x14, 0x28, 0x44, 0x0e, 0x2e, 0x3f, 0x17,
- 0x79, 0x2f, 0x42, 0x1b, 0x2b, 0xef, 0x8d, 0xb8, 0xb2, 0x96, 0xe3, 0x5b, 0x9c, 0xc3, 0x77, 0x55,
- 0xf5, 0x02, 0x9f, 0xee, 0x0b, 0xe8, 0xf9, 0x43, 0xa6, 0x1b, 0x3e, 0xc7, 0x2c, 0x3b, 0x10, 0xf7,
- 0xf7, 0xdc, 0xe5, 0x59, 0x8d, 0x13, 0x83, 0x6f, 0x76, 0x8e, 0x4d, 0xed, 0x0d, 0xe5, 0x6b, 0x45,
- 0xc1, 0xec, 0xf3, 0xfe, 0x24, 0x91, 0xd4, 0xea, 0xf7, 0x7e, 0x96, 0x38, 0xb3, 0xcc, 0x01, 0x97,
- 0x39, 0xa0, 0x90, 0x0d, 0xae, 0xa6, 0x95, 0xbb, 0xb5, 0x66, 0x86, 0xff, 0xcb, 0xe4, 0xf2, 0xbf,
- 0x03, 0x00, 0x00, 0xff, 0xff, 0x6b, 0x0b, 0xe3, 0x5c, 0x51, 0x2c, 0x00, 0x00,
+ // 3151 bytes of a gzipped FileDescriptorProto
+ 0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xcc, 0x3a, 0x4b, 0x6c, 0x1b, 0xd7,
+ 0xb5, 0x6f, 0x48, 0x8a, 0x22, 0x0f, 0x29, 0x91, 0xbe, 0x91, 0x65, 0x99, 0x8e, 0x63, 0x7b, 0x82,
+ 0xe4, 0xf9, 0xc9, 0x31, 0xe9, 0xd0, 0xcf, 0x4e, 0xa2, 0xfc, 0xaa, 0x0f, 0x1d, 0xdb, 0x91, 0x25,
+ 0x75, 0x28, 0x2b, 0x4e, 0x9b, 0x7a, 0x72, 0xc9, 0xb9, 0xa6, 0xa6, 0x26, 0x67, 0xe8, 0x99, 0x4b,
+ 0xd9, 0x72, 0x60, 0x14, 0x28, 0x90, 0x06, 0x48, 0x81, 0x14, 0x45, 0xbb, 0x69, 0xbb, 0x6a, 0x57,
+ 0x45, 0xd1, 0x65, 0x37, 0xfd, 0x6d, 0xba, 0x6a, 0xb7, 0x2d, 0xd0, 0x2e, 0xbb, 0xe9, 0xa2, 0x05,
+ 0xba, 0x2a, 0xd0, 0x5d, 0x17, 0xc5, 0xfd, 0xcc, 0x8f, 0x1c, 0x79, 0x48, 0xd9, 0x29, 0xba, 0xe2,
+ 0xcc, 0xb9, 0xe7, 0x77, 0xcf, 0x3d, 0xbf, 0x7b, 0x86, 0x70, 0xb9, 0x35, 0x30, 0xbb, 0x46, 0xad,
+ 0x85, 0x1f, 0x92, 0x6e, 0xcd, 0x21, 0x3d, 0x9b, 0x92, 0x1a, 0x79, 0x40, 0xda, 0x03, 0x6a, 0xda,
+ 0x56, 0x6d, 0xaf, 0x2e, 0x61, 0xba, 0x0f, 0xab, 0xf6, 0x1d, 0x9b, 0xda, 0xe8, 0x14, 0xa7, 0xab,
+ 0x72, 0xba, 0xaa, 0xc0, 0xa9, 0x06, 0x38, 0x7b, 0xf5, 0xca, 0xa9, 0x30, 0x63, 0x97, 0xf4, 0xf6,
+ 0x88, 0x23, 0x7f, 0x04, 0x87, 0xca, 0xb3, 0x1d, 0xdb, 0xee, 0x74, 0x49, 0x0d, 0xf7, 0xcd, 0x1a,
+ 0xb6, 0x2c, 0x9b, 0x62, 0x46, 0xea, 0xca, 0xd5, 0xe7, 0xe5, 0x6a, 0xd7, 0xb6, 0x3a, 0xce, 0xc0,
+ 0xb2, 0x4c, 0xab, 0x53, 0xb3, 0xfb, 0xc4, 0x89, 0x20, 0x3d, 0x27, 0x91, 0xf8, 0x5b, 0x6b, 0x70,
+ 0xa7, 0x66, 0x0c, 0x04, 0x82, 0x5c, 0x3f, 0x35, 0xbc, 0x4e, 0xcd, 0x1e, 0x71, 0x29, 0xee, 0xf5,
+ 0x25, 0xc2, 0x31, 0x89, 0xe0, 0xf4, 0xdb, 0x35, 0x97, 0x62, 0x3a, 0x90, 0x9c, 0xd5, 0x4f, 0x53,
+ 0x90, 0x5d, 0x6e, 0x33, 0x56, 0x68, 0x03, 0x66, 0xdb, 0x76, 0xaf, 0x87, 0x2d, 0x43, 0x37, 0xcc,
+ 0x0e, 0x71, 0xe9, 0x82, 0x72, 0x5a, 0x39, 0x5b, 0xa8, 0xff, 0x6f, 0x35, 0xc1, 0x04, 0xd5, 0x35,
+ 0x8e, 0xae, 0xcd, 0x48, 0x72, 0xf1, 0x8a, 0x9a, 0x70, 0xc4, 0xb4, 0xfa, 0x03, 0xaa, 0x3b, 0xb6,
+ 0x4d, 0x3d, 0x96, 0xa9, 0xc9, 0x58, 0x96, 0x38, 0x07, 0xcd, 0xb6, 0xa9, 0x64, 0x7a, 0x11, 0xa6,
+ 0xd9, 0xde, 0xec, 0x01, 0x5d, 0xc8, 0x72, 0x56, 0xc7, 0xab, 0x62, 0x6b, 0x55, 0x6f, 0xef, 0xd5,
+ 0x35, 0x69, 0x1b, 0xcd, 0xc3, 0x44, 0xa7, 0xa1, 0x68, 0xd8, 0xba, 0x65, 0x53, 0xbd, 0x8d, 0xdb,
+ 0xbb, 0x64, 0x61, 0xfa, 0xb4, 0x72, 0x36, 0xa7, 0x81, 0x61, 0x6f, 0xd8, 0x74, 0x95, 0x41, 0xae,
+ 0x67, 0x72, 0xe9, 0x72, 0x56, 0xfd, 0x61, 0x1a, 0xa6, 0x57, 0xc5, 0x1e, 0xd0, 0xb3, 0x90, 0xc7,
+ 0x4e, 0x67, 0xd0, 0x23, 0x16, 0x75, 0x17, 0x94, 0xd3, 0xe9, 0xb3, 0x79, 0x2d, 0x00, 0xa0, 0x7b,
+ 0x70, 0x94, 0x58, 0x7b, 0xa6, 0x63, 0x5b, 0xec, 0x5d, 0xdf, 0xc3, 0x8e, 0x89, 0x5b, 0x5d, 0xe2,
+ 0x2e, 0xa4, 0x4e, 0xa7, 0xcf, 0x16, 0xea, 0x6f, 0x24, 0xee, 0x4f, 0x8a, 0xa9, 0x36, 0x02, 0x2e,
+ 0x3b, 0x92, 0x89, 0x36, 0x47, 0x46, 0x81, 0x2e, 0x3a, 0x03, 0x45, 0x7b, 0x40, 0x99, 0x3d, 0xef,
+ 0x98, 0x4c, 0x52, 0x9a, 0xeb, 0x54, 0x10, 0xb0, 0x2b, 0x0c, 0x84, 0xce, 0x03, 0x92, 0x28, 0x86,
+ 0xe9, 0x90, 0x36, 0xb5, 0x1d, 0x93, 0xb8, 0x0b, 0x19, 0x8e, 0x78, 0x44, 0xac, 0xac, 0x05, 0x0b,
+ 0xa8, 0x01, 0xb9, 0x7e, 0x17, 0xd3, 0x3b, 0xb6, 0xd3, 0x5b, 0x98, 0xe2, 0xc6, 0xfc, 0xbf, 0x44,
+ 0xbd, 0xb7, 0x24, 0x81, 0xe6, 0x93, 0xa2, 0x73, 0x70, 0xe4, 0xbe, 0xed, 0xdc, 0x35, 0xad, 0x8e,
+ 0x2f, 0x76, 0x9f, 0x1f, 0x4e, 0x5e, 0x2b, 0xcb, 0x05, 0x4f, 0xea, 0x7e, 0xe5, 0x6d, 0x78, 0x26,
+ 0x66, 0xcb, 0x08, 0x41, 0xc6, 0xc2, 0x3d, 0xc2, 0x3d, 0x2e, 0xaf, 0xf1, 0x67, 0x34, 0x07, 0x53,
+ 0x7b, 0xb8, 0x3b, 0x20, 0xdc, 0x67, 0xf2, 0x9a, 0x78, 0x51, 0xbf, 0xab, 0x40, 0xce, 0x53, 0x02,
+ 0x69, 0x00, 0x7d, 0x87, 0x45, 0x0b, 0x65, 0x1b, 0x55, 0xb8, 0xed, 0xeb, 0x63, 0xef, 0xa1, 0xba,
+ 0x25, 0x68, 0xf7, 0xb5, 0x10, 0x97, 0xca, 0xff, 0x43, 0xce, 0x83, 0x4f, 0xa0, 0xd6, 0x5f, 0x15,
+ 0xc8, 0xfb, 0xbb, 0x44, 0x6f, 0xc3, 0x94, 0x38, 0x24, 0xa1, 0x52, 0xb2, 0x59, 0xd9, 0xf9, 0x6d,
+ 0xd8, 0x06, 0xd1, 0x04, 0x1d, 0xda, 0x82, 0x42, 0xf8, 0x08, 0x85, 0x57, 0x55, 0xc7, 0x88, 0x1a,
+ 0xa9, 0x01, 0xe7, 0x15, 0x66, 0x81, 0xae, 0x42, 0xce, 0xdd, 0xef, 0x75, 0x4d, 0xeb, 0xae, 0x70,
+ 0x9d, 0x42, 0xfd, 0xa5, 0x44, 0x76, 0x4d, 0x41, 0xc0, 0x99, 0xf9, 0xd4, 0xea, 0xa7, 0x0a, 0xe4,
+ 0x3c, 0x7d, 0x63, 0x2d, 0xf4, 0x36, 0x64, 0x0f, 0x17, 0xed, 0x92, 0x0c, 0x3d, 0x0f, 0x33, 0xa6,
+ 0x2b, 0x33, 0x31, 0x73, 0x8f, 0x85, 0x0c, 0x0f, 0xd8, 0xa2, 0xe9, 0x36, 0x7c, 0x18, 0x0f, 0xd9,
+ 0x8c, 0x6a, 0xc0, 0x4c, 0x64, 0xd3, 0x9f, 0x8b, 0x42, 0xea, 0x6b, 0x50, 0x08, 0xd9, 0x22, 0x56,
+ 0xc6, 0x3c, 0x64, 0x29, 0x76, 0x3a, 0x84, 0x4a, 0xbf, 0x90, 0x6f, 0xea, 0xeb, 0x90, 0x95, 0xa9,
+ 0x0b, 0x41, 0x66, 0x17, 0xbb, 0xbb, 0x1e, 0x15, 0x7b, 0x46, 0x27, 0x01, 0x5c, 0xf3, 0x21, 0xd1,
+ 0x5b, 0xfb, 0x94, 0x1f, 0xb3, 0x72, 0x36, 0xad, 0xe5, 0x19, 0x64, 0x85, 0x01, 0xd4, 0x3f, 0x67,
+ 0x61, 0x5e, 0x6c, 0x99, 0x18, 0x22, 0x4b, 0xdf, 0x20, 0x14, 0x1b, 0x98, 0x62, 0x26, 0x8f, 0x05,
+ 0x17, 0x71, 0x24, 0x3f, 0xf9, 0x86, 0x1a, 0x50, 0xbe, 0x37, 0x20, 0x03, 0x62, 0xe8, 0x7e, 0x0d,
+ 0x90, 0xbb, 0xae, 0x8c, 0x64, 0xca, 0x6d, 0x0f, 0x43, 0x2b, 0x09, 0x1a, 0x1f, 0x80, 0xb6, 0x60,
+ 0x5e, 0x30, 0xd4, 0x5d, 0x8a, 0x1d, 0x1a, 0x62, 0x96, 0x4e, 0x64, 0x36, 0x27, 0x28, 0x9b, 0x8c,
+ 0x30, 0xe0, 0x78, 0x0b, 0x2a, 0x92, 0x63, 0xdb, 0xee, 0xf5, 0xbb, 0x84, 0x46, 0x54, 0xcc, 0x24,
+ 0x72, 0x5d, 0x10, 0xd4, 0xab, 0x1e, 0x71, 0xc0, 0xf9, 0x7d, 0x38, 0x21, 0x0a, 0xcd, 0x1d, 0x42,
+ 0xdb, 0xbb, 0x23, 0x0a, 0x4f, 0x25, 0xb3, 0xe6, 0xe4, 0x57, 0x18, 0xf5, 0x90, 0xd2, 0x18, 0x4e,
+ 0x85, 0x59, 0xc7, 0x69, 0x9e, 0x4d, 0x64, 0xff, 0x6c, 0xc0, 0x3e, 0x46, 0xfb, 0x1d, 0x38, 0xee,
+ 0xbb, 0xde, 0x88, 0xee, 0xd3, 0x89, 0xcc, 0x8f, 0xf9, 0xc4, 0x43, 0xaa, 0xdf, 0x86, 0x93, 0x01,
+ 0xdf, 0x38, 0xc5, 0x73, 0x89, 0xbc, 0x4f, 0xf8, 0x0c, 0x62, 0xf4, 0xfe, 0x0a, 0x9c, 0x94, 0xc5,
+ 0x66, 0xd0, 0xef, 0xda, 0xd8, 0x18, 0xd1, 0x3d, 0x9f, 0xc8, 0xbf, 0x22, 0x18, 0xdc, 0xe4, 0xf4,
+ 0x43, 0xea, 0x13, 0x38, 0x13, 0x65, 0x1f, 0xb7, 0x05, 0x48, 0x14, 0xf1, 0x5c, 0x58, 0xc4, 0xe8,
+ 0x2e, 0xd4, 0x7f, 0x4c, 0x41, 0x51, 0x44, 0x96, 0x46, 0xdc, 0x41, 0x97, 0xa2, 0x8d, 0xa1, 0x32,
+ 0x2b, 0x52, 0xef, 0xb9, 0xc4, 0x8c, 0xb1, 0xe9, 0xd7, 0xe1, 0x68, 0x4d, 0xfe, 0x10, 0xe6, 0x42,
+ 0xfc, 0x74, 0x3f, 0x07, 0xc3, 0x98, 0x29, 0x5d, 0xf0, 0x95, 0xd9, 0x47, 0x43, 0x01, 0x6b, 0x09,
+ 0x72, 0x91, 0x1e, 0x5b, 0xf5, 0x45, 0x8e, 0xbf, 0x30, 0x26, 0x7f, 0x3f, 0x87, 0xc6, 0xf5, 0x09,
+ 0x5f, 0x85, 0xe3, 0x43, 0x02, 0xf6, 0x83, 0x7d, 0x14, 0x0e, 0xb5, 0x8f, 0x63, 0x51, 0x29, 0xfb,
+ 0xfe, 0x66, 0x4e, 0x40, 0x9e, 0x3c, 0x30, 0xa9, 0xde, 0xb6, 0x0d, 0x91, 0xf6, 0xa7, 0xb4, 0x1c,
+ 0x03, 0xac, 0xb2, 0xbc, 0xcb, 0xb2, 0x25, 0x35, 0x6c, 0xd6, 0x52, 0xe2, 0xfb, 0x3c, 0xae, 0x8b,
+ 0x5a, 0x5e, 0x40, 0x34, 0x7c, 0x1f, 0xad, 0xc3, 0x8c, 0x5c, 0x96, 0xd9, 0x3e, 0x3b, 0x59, 0xb6,
+ 0x2f, 0x0a, 0x6a, 0x99, 0xae, 0x85, 0x30, 0xe2, 0x38, 0x5c, 0xd8, 0xb4, 0x2f, 0x8c, 0x38, 0x4e,
+ 0x20, 0x8c, 0x2d, 0x4b, 0x61, 0xb9, 0xc9, 0x85, 0x11, 0xc7, 0x91, 0xc2, 0xee, 0x00, 0x0a, 0x82,
+ 0xb5, 0x27, 0x73, 0xbc, 0x8c, 0xa0, 0x57, 0x12, 0x59, 0xc6, 0x97, 0x08, 0xed, 0x88, 0x8f, 0xe4,
+ 0x81, 0xae, 0x67, 0x72, 0x4a, 0x39, 0xa5, 0xfe, 0x58, 0x01, 0x08, 0xfc, 0x95, 0x15, 0xa6, 0x3e,
+ 0xa6, 0x7e, 0x61, 0x62, 0xcf, 0xff, 0x99, 0x1a, 0x8e, 0x2a, 0x90, 0x6b, 0xdb, 0x16, 0xe5, 0x3d,
+ 0xb6, 0x38, 0x4e, 0xff, 0x5d, 0xd6, 0xf7, 0xcf, 0x14, 0xc8, 0x6c, 0x3b, 0x84, 0xa0, 0xb7, 0x20,
+ 0xc3, 0xee, 0x11, 0xf2, 0x4e, 0xb2, 0x38, 0x7e, 0x2b, 0xa4, 0x71, 0x3a, 0x74, 0x05, 0x72, 0xed,
+ 0x5d, 0xb3, 0x6b, 0x38, 0xc4, 0x92, 0x31, 0x3d, 0x09, 0x0f, 0x9f, 0x56, 0x1d, 0x40, 0x69, 0x28,
+ 0x64, 0x62, 0xed, 0x77, 0x15, 0x0a, 0xd4, 0x21, 0xc4, 0x73, 0x8e, 0xf4, 0x64, 0x46, 0x04, 0x46,
+ 0x2b, 0x9e, 0xaf, 0x67, 0x72, 0xa9, 0x72, 0x5a, 0x7d, 0x1d, 0x66, 0x22, 0x11, 0x14, 0x2b, 0xf4,
+ 0xa0, 0x1e, 0xe4, 0x3c, 0x94, 0x1a, 0x9e, 0x94, 0x2d, 0xbb, 0x6b, 0xb6, 0xf7, 0x99, 0xe5, 0xfb,
+ 0x8e, 0x69, 0x3b, 0x26, 0xdd, 0xe7, 0x2c, 0xa6, 0x34, 0xff, 0x5d, 0xbd, 0x00, 0x48, 0x24, 0x43,
+ 0x97, 0x5f, 0x8e, 0xc6, 0xa0, 0xf8, 0x38, 0x0d, 0xb3, 0xd2, 0x09, 0x35, 0x72, 0x6f, 0xe0, 0x9d,
+ 0xbf, 0xe5, 0x52, 0x6c, 0xb5, 0x89, 0x1e, 0x6a, 0x96, 0x8a, 0x1e, 0x70, 0x83, 0x35, 0x4d, 0x8b,
+ 0x70, 0xc4, 0xbd, 0x6b, 0xf6, 0xc5, 0xb5, 0x4c, 0xef, 0xda, 0xf6, 0xdd, 0x81, 0x68, 0x30, 0x72,
+ 0x5a, 0x89, 0x2d, 0x70, 0xf9, 0xeb, 0x1c, 0xcc, 0x02, 0x0e, 0x73, 0xff, 0x3e, 0x6c, 0x74, 0x0b,
+ 0x6a, 0x19, 0x70, 0x5f, 0x86, 0x72, 0x10, 0x70, 0x7d, 0xbe, 0x43, 0x59, 0x6c, 0x2f, 0x8c, 0x19,
+ 0x6e, 0xbe, 0x2d, 0xb5, 0x12, 0x19, 0x32, 0x2e, 0x81, 0x39, 0x47, 0x18, 0x50, 0xee, 0x4c, 0x0a,
+ 0x10, 0x29, 0xe2, 0x62, 0xa2, 0x80, 0x51, 0xeb, 0x6b, 0xc8, 0x19, 0x81, 0x09, 0xcf, 0xb8, 0x9e,
+ 0xc9, 0x65, 0xca, 0x53, 0xd7, 0x33, 0xb9, 0xa9, 0x72, 0x56, 0xbd, 0x07, 0xd3, 0xeb, 0x76, 0x87,
+ 0x07, 0x75, 0x10, 0xc0, 0xca, 0xe1, 0x02, 0xf8, 0x05, 0x98, 0xdd, 0x1d, 0xf4, 0xb0, 0xa5, 0x3b,
+ 0x04, 0x1b, 0x3c, 0x82, 0x53, 0xfc, 0x60, 0x66, 0x38, 0x54, 0x93, 0x40, 0xf5, 0x5b, 0x69, 0xcf,
+ 0xb9, 0x88, 0x46, 0xdc, 0xbe, 0x6d, 0xb9, 0x04, 0x35, 0x20, 0x2b, 0xd4, 0x95, 0xb2, 0xcf, 0x27,
+ 0xca, 0x0e, 0x97, 0x60, 0x4d, 0x12, 0x33, 0x17, 0xe2, 0xe6, 0x33, 0x74, 0xc9, 0x4d, 0x28, 0x50,
+ 0x14, 0x40, 0x59, 0xaf, 0x17, 0x21, 0x2b, 0x06, 0x1a, 0x32, 0xc6, 0x90, 0xd7, 0x0c, 0x38, 0xfd,
+ 0x76, 0xb5, 0xc9, 0x57, 0x34, 0x89, 0x81, 0x30, 0x14, 0x5c, 0xe2, 0xec, 0x11, 0x47, 0xef, 0xda,
+ 0x1d, 0x71, 0x31, 0x2e, 0xd4, 0xbf, 0x30, 0x6e, 0x7a, 0xf5, 0xb6, 0x57, 0x6d, 0x72, 0x1e, 0xeb,
+ 0x76, 0xc7, 0x6d, 0x58, 0xd4, 0xd9, 0xd7, 0xc0, 0xf5, 0x01, 0x68, 0x01, 0xa6, 0x7b, 0xc4, 0x75,
+ 0x71, 0x87, 0xf0, 0x84, 0x96, 0xd7, 0xbc, 0xd7, 0x4a, 0x07, 0x4a, 0x43, 0x84, 0xa8, 0x0c, 0xe9,
+ 0xbb, 0x64, 0x5f, 0x46, 0x06, 0x7b, 0x44, 0x6f, 0x85, 0x2f, 0x97, 0x85, 0xfa, 0xd9, 0x44, 0xdd,
+ 0xe4, 0x71, 0xcb, 0x6b, 0xe8, 0x52, 0xea, 0x55, 0x45, 0xc5, 0x5e, 0x2c, 0x8a, 0x9e, 0xb0, 0x43,
+ 0xd4, 0x4d, 0x98, 0xda, 0x61, 0xcb, 0xa8, 0x00, 0xd3, 0x37, 0x37, 0xde, 0xdd, 0xd8, 0x7c, 0x6f,
+ 0xa3, 0xfc, 0x3f, 0xa8, 0x04, 0x85, 0xd5, 0xe5, 0xd5, 0xab, 0x0d, 0x7d, 0xf5, 0x6a, 0x63, 0xf5,
+ 0xdd, 0xb2, 0x82, 0x00, 0xb2, 0x5f, 0xbc, 0xd9, 0xb8, 0xd9, 0x58, 0x2b, 0xa7, 0xd0, 0x0c, 0xe4,
+ 0x1b, 0xb7, 0x1a, 0xab, 0x37, 0xb7, 0xaf, 0x6d, 0xbc, 0x53, 0x4e, 0xb3, 0xd7, 0xd5, 0xcd, 0x1b,
+ 0x5b, 0xeb, 0x8d, 0xed, 0xc6, 0x5a, 0x39, 0xa3, 0x7e, 0x3b, 0x05, 0x0b, 0xd2, 0x2a, 0x9b, 0xde,
+ 0xac, 0xca, 0xbf, 0x99, 0xbc, 0x0b, 0x53, 0x2e, 0x13, 0xcb, 0xf7, 0x35, 0x5b, 0xbf, 0x34, 0x7e,
+ 0x3c, 0x71, 0x6d, 0xab, 0x5c, 0x55, 0x4d, 0xf0, 0x18, 0x8d, 0xfa, 0xd4, 0x93, 0x44, 0xfd, 0x4b,
+ 0x80, 0x64, 0x87, 0xe0, 0x52, 0x87, 0xe0, 0x9e, 0xc8, 0x4c, 0x69, 0x31, 0xab, 0x10, 0x2b, 0x4d,
+ 0xbe, 0xc0, 0xb3, 0x93, 0xc0, 0x66, 0x25, 0x3e, 0x8c, 0x9d, 0xf1, 0xb1, 0x89, 0xe3, 0x04, 0xd8,
+ 0xea, 0x22, 0xcc, 0xbd, 0x87, 0x4d, 0xea, 0x6f, 0xc6, 0x4b, 0x84, 0x31, 0x97, 0x45, 0xf5, 0xe3,
+ 0x14, 0xcc, 0xbf, 0x43, 0x68, 0xc4, 0xeb, 0x27, 0xc9, 0x9b, 0x4f, 0xd7, 0x2a, 0x5c, 0x64, 0xd7,
+ 0xb4, 0x88, 0x2e, 0x4c, 0x20, 0x33, 0x70, 0x51, 0x00, 0x9b, 0x1c, 0x16, 0x45, 0x22, 0x8e, 0xe3,
+ 0xd7, 0x73, 0x0f, 0x89, 0x38, 0x0e, 0xaa, 0xc2, 0x33, 0x12, 0x29, 0xd2, 0x43, 0x4f, 0x89, 0x09,
+ 0x94, 0x58, 0x0a, 0x1a, 0x0f, 0x57, 0xfd, 0x5d, 0x0a, 0x8e, 0xdf, 0xec, 0x1b, 0x98, 0x92, 0xff,
+ 0x12, 0x53, 0x68, 0x3e, 0x37, 0x99, 0x72, 0xd2, 0x87, 0x49, 0x60, 0x92, 0xa7, 0xcc, 0x50, 0x07,
+ 0x55, 0x83, 0xcc, 0x53, 0xad, 0x06, 0xea, 0xa7, 0x0a, 0x1c, 0xbb, 0x62, 0x5a, 0xc6, 0x0d, 0xd3,
+ 0x75, 0x4d, 0xab, 0xb3, 0xd2, 0xb5, 0x5b, 0xee, 0x44, 0x96, 0xbc, 0x0e, 0xc5, 0x56, 0xd7, 0x6e,
+ 0x49, 0x3b, 0x7a, 0x37, 0x9f, 0xb1, 0x0d, 0x59, 0x60, 0xc4, 0xe2, 0xd9, 0x55, 0x07, 0xb0, 0x30,
+ 0xaa, 0x8b, 0xac, 0x0e, 0xef, 0xc3, 0x5c, 0x4f, 0xc0, 0xf5, 0x27, 0x91, 0x87, 0x7a, 0x01, 0x73,
+ 0x4f, 0xec, 0xbf, 0x14, 0x38, 0xb6, 0x82, 0x69, 0x7b, 0x57, 0x38, 0xd5, 0xe4, 0x36, 0xf8, 0x00,
+ 0x72, 0x8e, 0xc0, 0xf7, 0xf4, 0x49, 0x2e, 0x0f, 0x07, 0x08, 0xac, 0xca, 0x5f, 0xcd, 0xe7, 0x58,
+ 0xb9, 0x0d, 0xd3, 0x9e, 0x36, 0x4f, 0x5c, 0x9e, 0x11, 0x64, 0xf8, 0x1d, 0x21, 0xc5, 0xdb, 0x66,
+ 0xfe, 0xac, 0xfe, 0x53, 0x81, 0x85, 0x51, 0x6d, 0xa4, 0xd9, 0x3f, 0x84, 0xbc, 0x23, 0x9f, 0xbd,
+ 0xb9, 0xe4, 0xca, 0x21, 0xf6, 0x26, 0x6b, 0xa0, 0xf7, 0xa0, 0x05, 0x4c, 0x2b, 0xf7, 0x21, 0xe7,
+ 0x4b, 0x7b, 0xe2, 0xfd, 0x05, 0x75, 0x3d, 0x95, 0x54, 0xd7, 0xd5, 0xaf, 0xc1, 0x51, 0xae, 0x28,
+ 0x6b, 0x4a, 0x26, 0x3f, 0xf3, 0x65, 0x98, 0x3e, 0xa4, 0x0b, 0x7a, 0x74, 0xea, 0x37, 0x52, 0x30,
+ 0x3f, 0xac, 0x81, 0x34, 0xc4, 0xed, 0x51, 0xb3, 0x8f, 0xe9, 0x52, 0x23, 0xbc, 0x62, 0x8d, 0xfe,
+ 0x4d, 0xe5, 0x69, 0x5a, 0x3d, 0xc6, 0xab, 0x26, 0xe9, 0xb0, 0xd4, 0x5f, 0x2a, 0x30, 0xfb, 0x0e,
+ 0xa1, 0xec, 0xc6, 0x36, 0xd1, 0x19, 0x5c, 0x85, 0xc2, 0x13, 0x7c, 0x25, 0x02, 0x27, 0xf8, 0x40,
+ 0x74, 0x02, 0xf2, 0x7d, 0xdc, 0x21, 0xba, 0x6b, 0x3e, 0x14, 0x95, 0x9d, 0xdd, 0x53, 0x70, 0x87,
+ 0x34, 0xcd, 0x87, 0x7c, 0x80, 0xc0, 0x17, 0xa9, 0x7d, 0x97, 0x58, 0xb2, 0x92, 0x73, 0xf4, 0x6d,
+ 0x06, 0x50, 0x3f, 0x51, 0xa0, 0xe4, 0x6b, 0x2f, 0x4d, 0xba, 0x1e, 0x9d, 0xc4, 0x2b, 0x13, 0x5f,
+ 0x1d, 0x23, 0x53, 0xf8, 0x17, 0xa1, 0x64, 0x91, 0x07, 0x54, 0x0f, 0x69, 0x21, 0xae, 0x6a, 0x33,
+ 0x0c, 0xbc, 0xe5, 0x6b, 0xf2, 0x26, 0xef, 0x0f, 0x56, 0x71, 0x1f, 0xb7, 0xcc, 0xae, 0x49, 0x4d,
+ 0x32, 0x91, 0x4b, 0xab, 0xbf, 0x49, 0x03, 0x12, 0xcd, 0x66, 0x98, 0x05, 0xc2, 0x80, 0x44, 0x05,
+ 0x6a, 0x87, 0xa0, 0xd2, 0x55, 0x92, 0x3f, 0x9b, 0xf0, 0x62, 0x13, 0x51, 0xe9, 0x48, 0x7b, 0x18,
+ 0x84, 0x7a, 0x30, 0x1f, 0x9a, 0x3a, 0x86, 0xc5, 0x88, 0x33, 0xbd, 0x3c, 0x7e, 0x37, 0x18, 0x11,
+ 0x75, 0x94, 0xc4, 0x81, 0xd1, 0x16, 0xcc, 0x1b, 0xa4, 0xef, 0x90, 0x36, 0xa6, 0xc4, 0xd0, 0x71,
+ 0xdf, 0xd4, 0xf7, 0x88, 0xe3, 0x9a, 0xb6, 0xe5, 0x8f, 0xa9, 0xc3, 0xe2, 0xe4, 0x67, 0xd9, 0x26,
+ 0xe9, 0xed, 0x10, 0x47, 0x9b, 0x0b, 0x28, 0x97, 0xfb, 0xe6, 0x8e, 0xa0, 0x43, 0x2b, 0x50, 0xea,
+ 0xda, 0xf7, 0x23, 0xac, 0x32, 0x89, 0xac, 0x66, 0xba, 0xf6, 0xfd, 0x10, 0x8f, 0x35, 0x28, 0xef,
+ 0x9a, 0x9d, 0xdd, 0x08, 0x93, 0xa9, 0x44, 0x26, 0xb3, 0x8c, 0x26, 0xe0, 0xa2, 0x6e, 0xc0, 0xac,
+ 0xf0, 0xe9, 0x2b, 0x03, 0x8b, 0xf7, 0x13, 0xea, 0x1b, 0xb1, 0x7d, 0x3c, 0x40, 0xb6, 0x79, 0x75,
+ 0xb9, 0x7e, 0xe9, 0x72, 0x59, 0x41, 0x39, 0xc8, 0x34, 0xaf, 0x2e, 0xbf, 0x5c, 0x4e, 0xa1, 0x69,
+ 0x48, 0xdf, 0x58, 0xbb, 0x54, 0x4e, 0xb3, 0x87, 0x9d, 0xe6, 0x66, 0x39, 0xa3, 0x5e, 0x81, 0x93,
+ 0xa2, 0x4b, 0xe1, 0x07, 0x29, 0x92, 0x7a, 0xc4, 0x98, 0x2f, 0xc0, 0xec, 0x80, 0x43, 0x75, 0x62,
+ 0xb1, 0xbb, 0x9d, 0xc1, 0x5d, 0x23, 0xa7, 0xcd, 0x08, 0x68, 0x43, 0x00, 0xd5, 0xdf, 0x2b, 0x30,
+ 0xb7, 0x25, 0x6f, 0xfe, 0x11, 0xfa, 0x36, 0x80, 0x9c, 0x08, 0x04, 0x91, 0xb2, 0x9a, 0xfc, 0x35,
+ 0x2e, 0x86, 0x95, 0x0f, 0xd4, 0xb0, 0xd5, 0x21, 0x5a, 0x88, 0x6d, 0xe5, 0x26, 0xcc, 0x44, 0x16,
+ 0xd1, 0x19, 0x28, 0xf6, 0x4c, 0x4b, 0x1f, 0x9a, 0x4d, 0x14, 0x7a, 0xa6, 0xe5, 0xe1, 0x71, 0x14,
+ 0xfc, 0x20, 0x40, 0x49, 0x49, 0x14, 0xfc, 0xc0, 0x43, 0x51, 0xb7, 0xe0, 0x84, 0x9c, 0xac, 0x2c,
+ 0xb7, 0x5c, 0xbb, 0x3b, 0xa0, 0x64, 0x0b, 0xd3, 0xdd, 0x26, 0x75, 0x30, 0x25, 0x9d, 0x7d, 0xf5,
+ 0xe5, 0x58, 0xcb, 0xcf, 0x02, 0xac, 0x5d, 0x6b, 0x2e, 0xaf, 0xaf, 0x6f, 0xbe, 0xd7, 0x58, 0x2b,
+ 0x2b, 0x6c, 0xd1, 0x7b, 0x49, 0xa9, 0xbf, 0xc8, 0xc0, 0x91, 0x91, 0x90, 0x41, 0xb7, 0xa1, 0x24,
+ 0x72, 0x9c, 0x7e, 0x47, 0x9e, 0x2a, 0x37, 0xd4, 0x38, 0xd7, 0xa4, 0xa8, 0x33, 0xc8, 0x6b, 0xd2,
+ 0xac, 0x11, 0x81, 0xa2, 0x4f, 0x14, 0x38, 0x2d, 0x3b, 0x58, 0x11, 0xea, 0xf2, 0x44, 0x63, 0x42,
+ 0xf1, 0xad, 0x31, 0x9b, 0xda, 0x03, 0xdc, 0x45, 0x3b, 0x89, 0x1f, 0xeb, 0x4d, 0x03, 0x38, 0x21,
+ 0xdb, 0x5d, 0x69, 0xe3, 0xa8, 0x0e, 0x22, 0x3e, 0x2f, 0x1d, 0xca, 0x3d, 0xb4, 0xe3, 0x9c, 0x73,
+ 0xac, 0x13, 0x2e, 0x41, 0x85, 0x9d, 0x75, 0x8b, 0x55, 0x50, 0x9d, 0xda, 0x14, 0x77, 0xf5, 0xd0,
+ 0x17, 0xb6, 0x0c, 0xff, 0xc2, 0x36, 0xdf, 0xc3, 0x0f, 0x78, 0x89, 0xdd, 0x66, 0xeb, 0x4d, 0xef,
+ 0x73, 0x1b, 0x33, 0xde, 0x73, 0x72, 0xb0, 0xad, 0x63, 0xe9, 0x06, 0x7a, 0x1f, 0xd3, 0x5d, 0x76,
+ 0x01, 0xe4, 0x8e, 0xc0, 0xc3, 0x78, 0x76, 0x8c, 0xc6, 0xe9, 0x31, 0xce, 0x24, 0x4f, 0xee, 0x84,
+ 0xfb, 0x18, 0x7f, 0xfb, 0x5e, 0x0a, 0x8e, 0xc6, 0x26, 0xc2, 0x78, 0x07, 0x52, 0x9e, 0x9e, 0x03,
+ 0x9d, 0x81, 0x22, 0x23, 0xf2, 0x53, 0x80, 0x98, 0xb9, 0x14, 0x18, 0x4c, 0x26, 0x00, 0xf4, 0x08,
+ 0x4e, 0x85, 0x66, 0x67, 0x4f, 0xff, 0x74, 0x83, 0xef, 0x56, 0x71, 0xcb, 0xea, 0x0d, 0x28, 0x6c,
+ 0xdb, 0x76, 0x77, 0x8d, 0x50, 0x6c, 0x76, 0xf9, 0x17, 0x03, 0x6a, 0xdb, 0xdd, 0x70, 0x31, 0xcc,
+ 0x31, 0x00, 0xef, 0x2b, 0xce, 0x40, 0x91, 0x2f, 0x7a, 0x59, 0x58, 0x14, 0xdb, 0x02, 0x83, 0x79,
+ 0x69, 0xf6, 0x6f, 0x0a, 0x94, 0x64, 0x71, 0xf5, 0x47, 0x18, 0x9b, 0x92, 0xcc, 0x10, 0x32, 0x64,
+ 0x89, 0x4c, 0xfe, 0x60, 0x1e, 0xd2, 0x4b, 0x08, 0x09, 0x29, 0x29, 0xa3, 0xd2, 0x34, 0xa4, 0x12,
+ 0x39, 0x01, 0xb8, 0x66, 0xa0, 0x97, 0x00, 0x71, 0x69, 0xa6, 0xb5, 0x67, 0xb7, 0xb1, 0x87, 0x25,
+ 0xa7, 0x12, 0x6c, 0xe5, 0x9a, 0xbf, 0x70, 0xcd, 0x40, 0x4b, 0x70, 0xbc, 0x6d, 0x3b, 0x0e, 0xe9,
+ 0xf2, 0x92, 0x17, 0xd0, 0xb8, 0x8c, 0x48, 0xb4, 0x34, 0xc7, 0x02, 0x84, 0x80, 0xd4, 0xbd, 0x66,
+ 0xd4, 0x7f, 0x9e, 0x82, 0xbc, 0xef, 0x56, 0xe8, 0x33, 0x05, 0xa6, 0xe5, 0x14, 0x07, 0xd5, 0xc6,
+ 0x9f, 0x82, 0x71, 0x53, 0x55, 0x4e, 0x7a, 0x5d, 0x60, 0xe8, 0x8f, 0x4b, 0x55, 0x7f, 0x18, 0xa4,
+ 0xbe, 0xfc, 0xf5, 0x3f, 0xfc, 0xe5, 0x3b, 0xa9, 0x73, 0xea, 0x8b, 0xb5, 0xbd, 0x7a, 0xed, 0xa3,
+ 0x48, 0xc7, 0xf2, 0xe6, 0xe2, 0xe2, 0xa3, 0x9a, 0xd8, 0xbc, 0xbb, 0x24, 0x44, 0x90, 0x25, 0x65,
+ 0xf1, 0x82, 0x82, 0xbe, 0xaf, 0xc0, 0x4c, 0x64, 0x86, 0x82, 0x92, 0x3d, 0x28, 0x6e, 0xe6, 0x32,
+ 0x99, 0x72, 0x5c, 0xa7, 0xe0, 0x2f, 0x57, 0xb5, 0xc5, 0xc5, 0x47, 0x4b, 0xf7, 0xc3, 0x5c, 0xb9,
+ 0x72, 0xf5, 0x3f, 0xa6, 0xa1, 0x10, 0x4a, 0x88, 0xe8, 0x4f, 0xa2, 0x59, 0x8c, 0x7c, 0x3c, 0x4c,
+ 0xfe, 0x54, 0x13, 0x3f, 0xf5, 0xa9, 0x4c, 0x36, 0x60, 0x50, 0x3f, 0xe0, 0x1b, 0xd8, 0x41, 0xdb,
+ 0x8f, 0xb5, 0xae, 0x1c, 0x1c, 0xd4, 0x3e, 0x8a, 0x0c, 0x48, 0xaa, 0xbb, 0xd8, 0xdd, 0x7d, 0x34,
+ 0x0c, 0x0c, 0x72, 0xe4, 0x23, 0xf4, 0x77, 0x05, 0xd0, 0xe8, 0x54, 0x06, 0x2d, 0x25, 0xea, 0x78,
+ 0xe0, 0x28, 0x67, 0xd2, 0xfd, 0xdd, 0xe5, 0xfb, 0x23, 0x95, 0xcf, 0x65, 0x7f, 0x4b, 0xd1, 0x11,
+ 0x4f, 0xfd, 0x07, 0x59, 0x38, 0xbe, 0x2a, 0xbe, 0x3a, 0x2d, 0x1b, 0x86, 0x43, 0x5c, 0x97, 0xa5,
+ 0xb9, 0x26, 0xb5, 0x1d, 0xdc, 0x21, 0xe8, 0x57, 0x0a, 0x94, 0x87, 0x47, 0x19, 0xe8, 0xd5, 0x31,
+ 0xfe, 0xd0, 0x13, 0x3b, 0x89, 0xa9, 0xbc, 0x76, 0x08, 0x4a, 0x71, 0x13, 0x51, 0x2f, 0x72, 0xa3,
+ 0x9c, 0x57, 0xcf, 0x1e, 0x60, 0x94, 0x16, 0xc3, 0x5e, 0xba, 0x13, 0x90, 0x2f, 0x29, 0x8b, 0x5c,
+ 0xfd, 0xe1, 0x4b, 0xfc, 0x18, 0xea, 0x1f, 0x30, 0xd3, 0x18, 0x43, 0xfd, 0x83, 0x26, 0x06, 0x63,
+ 0xaa, 0xdf, 0x0a, 0xc8, 0x99, 0xfa, 0x3f, 0x53, 0x60, 0x36, 0x7a, 0x19, 0x46, 0x97, 0x27, 0xbe,
+ 0x3d, 0x0b, 0xd5, 0x5f, 0x39, 0xe4, 0xad, 0x3b, 0x31, 0x95, 0x85, 0x14, 0x67, 0xc4, 0x4c, 0xed,
+ 0xdf, 0x2a, 0x30, 0x2d, 0x2f, 0x92, 0x63, 0x64, 0xd6, 0xe8, 0x85, 0xb9, 0x72, 0x61, 0x7c, 0x02,
+ 0xa9, 0xe1, 0x2d, 0xae, 0xa1, 0x86, 0xb6, 0x1e, 0xa7, 0x61, 0xed, 0xa3, 0xd0, 0x0d, 0xdb, 0x0b,
+ 0x92, 0x30, 0x28, 0x1c, 0x22, 0x1d, 0x21, 0xe1, 0x82, 0x52, 0xff, 0xb5, 0x02, 0xc5, 0x48, 0x03,
+ 0xf2, 0x53, 0x91, 0xf7, 0x22, 0xb0, 0xb1, 0xf2, 0x5e, 0xcc, 0x6d, 0xb6, 0x92, 0x3c, 0xfd, 0x1c,
+ 0xbd, 0xc6, 0xaa, 0xe7, 0xf8, 0x76, 0x5f, 0x40, 0xcf, 0x1f, 0xb0, 0xdd, 0x70, 0x27, 0xb2, 0xe2,
+ 0x40, 0xd2, 0x3f, 0x78, 0x57, 0xe6, 0x34, 0x0e, 0x0c, 0x3e, 0xeb, 0x39, 0x36, 0xb5, 0xb7, 0x94,
+ 0x2f, 0x95, 0x04, 0xb2, 0x8f, 0xfb, 0xa3, 0x54, 0x5a, 0x6b, 0xdc, 0xfa, 0x49, 0xea, 0xd4, 0x0a,
+ 0x67, 0xb8, 0xc2, 0x19, 0x0a, 0xda, 0xe0, 0xd6, 0x5a, 0xdd, 0xa9, 0xb7, 0xb2, 0xfc, 0x8f, 0x28,
+ 0x17, 0xff, 0x1d, 0x00, 0x00, 0xff, 0xff, 0xaa, 0x97, 0x89, 0x86, 0x74, 0x2c, 0x00, 0x00,
}
// Reference imports to suppress errors if they are not otherwise used.
diff --git a/build/bazel/remote/execution/v2/remote_execution.proto b/build/bazel/remote/execution/v2/remote_execution.proto
index 9138ec5..ee4b0b8 100644
--- a/build/bazel/remote/execution/v2/remote_execution.proto
+++ b/build/bazel/remote/execution/v2/remote_execution.proto
@@ -1084,14 +1084,10 @@ message ExecuteResponse {
string message = 5;
}
-// Metadata about an ongoing
-// [execution][build.bazel.remote.execution.v2.Execution.Execute], which
-// will be contained in the [metadata
-// field][google.longrunning.Operation.response] of the
-// [Operation][google.longrunning.Operation].
-message ExecuteOperationMetadata {
- // The current stage of execution.
- enum Stage {
+// The current stage of action execution.
+message ExecutionStage {
+ enum Value {
+ // Invalid value.
UNKNOWN = 0;
// Checking the result against the cache.
@@ -1106,8 +1102,16 @@ message ExecuteOperationMetadata {
// Finished execution.
COMPLETED = 4;
}
+}
- Stage stage = 1;
+// Metadata about an ongoing
+// [execution][build.bazel.remote.execution.v2.Execution.Execute], which
+// will be contained in the [metadata
+// field][google.longrunning.Operation.response] of the
+// [Operation][google.longrunning.Operation].
+message ExecuteOperationMetadata {
+ // The current stage of execution.
+ ExecutionStage.Value stage = 1;
// The digest of the [Action][build.bazel.remote.execution.v2.Action]
// being executed.
@@ -1350,22 +1354,24 @@ message ServerCapabilities {
// The digest function used for converting values into keys for CAS and Action
// Cache.
-enum DigestFunction {
- // It is an error for the server to return this value.
- UNKNOWN = 0;
+message DigestFunction {
+ enum Value {
+ // It is an error for the server to return this value.
+ UNKNOWN = 0;
- // The Sha-256 digest function.
- SHA256 = 1;
+ // The Sha-256 digest function.
+ SHA256 = 1;
- // The Sha-1 digest function.
- SHA1 = 2;
+ // The Sha-1 digest function.
+ SHA1 = 2;
- // The MD5 digest function.
- MD5 = 3;
+ // The MD5 digest function.
+ MD5 = 3;
- // The Microsoft "VSO-Hash" paged SHA256 digest function.
- // See https://github.com/microsoft/BuildXL/blob/master/Documentation/Specs/PagedHash.md .
- VSO = 4;
+ // The Microsoft "VSO-Hash" paged SHA256 digest function.
+ // See https://github.com/microsoft/BuildXL/blob/master/Documentation/Specs/PagedHash.md .
+ VSO = 4;
+ }
}
// Describes the server/instance capabilities for updating the action cache.
@@ -1385,10 +1391,10 @@ message PriorityCapabilities {
repeated PriorityRange priorities = 1;
}
-// Capabilities of the remote cache system.
-message CacheCapabilities {
- // Describes how the server treats absolute symlink targets.
- enum SymlinkAbsolutePathStrategy {
+// Describes how the server treats absolute symlink targets.
+message SymlinkAbsolutePathStrategy {
+ enum Value {
+ // Invalid value.
UNKNOWN = 0;
// Server will return an `INVALID_ARGUMENT` on input symlinks with absolute
@@ -1401,10 +1407,13 @@ message CacheCapabilities {
// resulting in non-hermetic builds.
ALLOWED = 2;
}
+}
+// Capabilities of the remote cache system.
+message CacheCapabilities {
// All the digest functions supported by the remote cache.
// Remote cache may support multiple digest functions simultaneously.
- repeated DigestFunction digest_function = 1;
+ repeated DigestFunction.Value digest_function = 1;
// Capabilities for updating the action cache.
ActionCacheUpdateCapabilities action_cache_update_capabilities = 2;
@@ -1419,13 +1428,13 @@ message CacheCapabilities {
int64 max_batch_total_size_bytes = 4;
// Whether absolute symlink targets are supported.
- SymlinkAbsolutePathStrategy symlink_absolute_path_strategy = 5;
+ SymlinkAbsolutePathStrategy.Value symlink_absolute_path_strategy = 5;
}
// Capabilities of the remote execution system.
message ExecutionCapabilities {
// Remote execution may only support a single digest function.
- DigestFunction digest_function = 1;
+ DigestFunction.Value digest_function = 1;
// Whether remote execution is enabled for the particular server/instance.
bool exec_enabled = 2;